@@ -3,8 +3,6 @@ import json
 import os
 from abc import abstractmethod, ABC
 
-import cirrocumulus.diff_exp
-
 
 class AbstractDataset(ABC):
 
@@ -16,26 +14,9 @@ class AbstractDataset(ABC):
         pass
 
     @abstractmethod
-    def read(self, file_system, path, obs_keys=[], var_keys=[], basis=None, dataset=None):
+    def read_dataset(self, file_system, path, keys=None, dataset=None):
         pass
 
-    def diff_exp(self, file_system, path, mask, dataset, schema, var_range):
-        var_names = schema['var']
-        start = var_range[0]
-        end = var_range[1]
-        if end - start > 5000:
-            raise ValueError()
-        var_names = var_names[start:end]
-        adata = self.read(file_system, path, obs_keys=[], var_keys=var_names, basis=[],
-            dataset=dataset, schema=schema)
-        result = cirrocumulus.diff_exp.diff_exp(adata.X, mask)
-        result['name'] = var_names
-        # if result is None:
-        #     result = batch_result
-        # else:
-        #     for key in batch_result:
-        #         result[key] = np.concatenate((result[key], batch_result[key]))
-        return result
 
     def has_precomputed_stats(self, file_system, path, dataset):
         return file_system.exists(os.path.join(path, 'stats'))
