@@ -1,9 +1,9 @@
 import datetime
 import json
 
+from cirrocumulus.database_api import get_email_domain
 from google.cloud import datastore
 
-from cirrocumulus.database_api import get_email_domain
 from .invalid_usage import InvalidUsage
 
 DATASET = 'Dataset'
@@ -12,6 +12,7 @@ DATASET_FILTER = 'Dataset_Filter'
 FEATURE_SET = 'F_Set'
 USER = 'User'
 JOB = 'Job'
+JOB_RESULT = 'Job_Result'
 
 
 class FirestoreDatastore:
@@ -19,6 +20,21 @@ class FirestoreDatastore:
     def __init__(self):
         self.datastore_client = datastore.Client()
 
+    def __get_key_and_dataset(self, email, dataset_id, ensure_owner=False):
+        client = self.datastore_client
+        key = client.key(DATASET, int(dataset_id))
+        dataset = client.get(key)
+        if dataset is None:
+            raise InvalidUsage('Please provide a valid id', 400)
+        readers = dataset.get('readers')
+
+        domain = get_email_domain(email)
+        if email not in readers and domain not in readers:
+            raise InvalidUsage('Not authorized', 403)
+        if ensure_owner and email not in dataset['owners']:
+            raise InvalidUsage('Not authorized', 403)
+        return key, dataset
+
     def server(self):
         client = self.datastore_client
         return dict(mode='server', email=client.project + '@appspot.gserviceaccount.com')
@@ -54,7 +70,7 @@ class FirestoreDatastore:
         user = client.get(key)
         if user is None:
             user = datastore.Entity(client.key(USER, email))
-        user.update({'last_login': datetime.datetime.now()})
+        user.update({'last_login': datetime.datetime.utcnow()})
         client.put(user)
         return user
 
@@ -66,7 +82,7 @@ class FirestoreDatastore:
         for result in query.fetch():
             results.append(
                 {'id': result.id, 'name': result['name'], 'title': result.get('title'),
-                 'owner': email in result['owners'], 'url': result['url']})
+                 'owner': email in result['owners'], 'species': result.get('species'), 'url': result['url']})
         domain = get_email_domain(email)
         if domain is not None:
             query = client.query(kind=DATASET)
@@ -77,6 +93,7 @@ class FirestoreDatastore:
             for result in query.fetch():
                 if result.id not in unique_ids:
                     results.append({'id': result.id, 'name': result['name'], 'title': result.get('title'),
+                                    'species': result.get('species'),
                                     'owner': email in result['owners'],
                                     'url': result['url']})
         return results
@@ -131,21 +148,6 @@ class FirestoreDatastore:
         client.put(dataset_filter_entity)
         return dataset_filter_entity.id
 
-    def __get_key_and_dataset(self, email, dataset_id, ensure_owner=False):
-        client = self.datastore_client
-        key = client.key(DATASET, int(dataset_id))
-        dataset = client.get(key)
-        if dataset is None:
-            raise InvalidUsage('Please provide a valid id', 400)
-        readers = dataset.get('readers')
-
-        domain = get_email_domain(email)
-        if email not in readers and domain not in readers:
-            raise InvalidUsage('Not authorized', 403)
-        if ensure_owner and email not in dataset['owners']:
-            raise InvalidUsage('Not authorized', 403)
-        return key, dataset
-
     def delete_dataset(self, email, dataset_id):
         client = self.datastore_client
         key, dataset = self.__get_key_and_dataset(email, dataset_id, True)
@@ -156,12 +158,12 @@ class FirestoreDatastore:
         dataset['id'] = dataset.id
         return dataset
 
-    def upsert_dataset(self, email, dataset_id, dataset_name, url, readers, description, title):
+    def upsert_dataset(self, email, dataset_id, dataset_name, url, readers, description, title, species):
         client = self.datastore_client
         if dataset_id is not None:  # only owner can update
             key, dataset = self.__get_key_and_dataset(email, dataset_id, True)
         else:
-            dataset = datastore.Entity(client.key(DATASET), exclude_from_indexes=['url', 'precomputed'])
+            dataset = datastore.Entity(client.key(DATASET), exclude_from_indexes=['url'])
             user = client.get(client.key(USER, email))
             if 'importer' not in user or not user['importer']:
                 raise InvalidUsage('Not authorized', 403)
@@ -173,7 +175,8 @@ class FirestoreDatastore:
                        'readers': list(readers),
                        'description': description,
                        'title': title,
-                       'url': url}
+                       'url': url,
+                       'species': species}
 
         if dataset_id is None:  # new dataset
             update_dict['owners'] = [email]
@@ -228,25 +231,67 @@ class FirestoreDatastore:
         client.put(entity)
         return entity.id
 
-    def create_job(self, email, dataset_id, params):
+    def create_job(self, email, dataset_id, job_name, job_type, params):
         dataset_id = int(dataset_id)
         client = self.datastore_client
         self.__get_key_and_dataset(email, dataset_id)
-        entity = datastore.Entity(client.key(JOB))
-        entity.update(dict(dataset_id=dataset_id, params=params))
+        entity = datastore.Entity(client.key(JOB), exclude_from_indexes=["params"])
+        import json
+        entity.update(dict(dataset_id=dataset_id, email=email, name=job_name, type=job_type, status='',
+            submitted=datetime.datetime.utcnow(), params=json.dumps(params)))
         client.put(entity)
-        return entity.id
+        job_id = entity.id
 
-    def get_job(self, email, job_id):
+        entity = datastore.Entity(client.key(JOB_RESULT, job_id), exclude_from_indexes=["result"])
+        entity.update(dict(dataset_id=dataset_id))
+        client.put(entity)
+        return str(job_id)
+
+    def get_job(self, email, job_id, return_result):
         client = self.datastore_client
-        entity = client.get(client.key(JOB, job_id))
-        self.__get_key_and_dataset(email, entity['dataset_id'])
-        entity['id'] = JOB
-        return entity
+        job_id = int(job_id)
+        key = client.key(JOB_RESULT if return_result else JOB, job_id)
+        result = client.get(key)
+        self.__get_key_and_dataset(email, result['dataset_id'])
+        return dict(status=result['result' if return_result else 'status'])
 
     def update_job(self, email, job_id, status, result):
         client = self.datastore_client
-        entity = client.get(client.key(JOB, job_id))
-        self.__get_key_and_dataset(email, entity['dataset_id'])
-        entity.update(dict(status=status, result=result))
+        job_id = int(job_id)
+        is_complete = result is not None
+        key = client.key(JOB, job_id)
+        entity = client.get(key)
+        if not is_complete:
+            self.__get_key_and_dataset(email, entity['dataset_id'])
+        entity.update(dict(status=status))
         client.put(entity)
+
+        if is_complete:
+            key = client.key(JOB_RESULT, job_id)
+            entity = client.get(key)
+            entity.update(dict(result=result))
+            client.put(entity)
+
+    def get_jobs(self, email, dataset_id):
+        client = self.datastore_client
+        query = client.query(kind=JOB)
+        dataset_id = int(dataset_id)
+        self.__get_key_and_dataset(email, dataset_id, False)
+        query.add_filter('dataset_id', '=', dataset_id)
+        results = []
+        for result in query.fetch():
+            results.append(
+                dict(id=result.id, name=result['name'], type=result['type'], submitted=result['submitted'],
+                    status=result['status'], email=result['email']))
+        return results
+
+    def delete_job(self, email, job_id):
+        client = self.datastore_client
+        job_id = int(job_id)
+        key = client.key(JOB, job_id)
+        result = client.get(key)
+        if result['email'] == email:
+            client.delete(key)
+            client.delete(client.key(JOB_RESULT, job_id))
+        else:
+            raise InvalidUsage('Not authorized', 403)
