@@ -23,11 +23,13 @@ import {
 import AppHeader from './AppHeader';
 import DeleteDatasetDialog from './DeleteDatasetDialog';
 import DistributionPlots from './DistributionPlots';
+import DraggableDivider from './DraggableDivider';
 import EditDatasetDialog from './EditDatasetDialog';
 import EmbeddingCharts from './EmbeddingCharts';
 import GalleryCharts from './GalleryCharts';
 import HelpDialog from './HelpDialog';
 import JobResultsPanel from './JobResultsPanel';
+import {LandingPage} from './LandingPage';
 import MoreOptionsDialog from './MoreOptionsDialog';
 import SaveDatasetFilterDialog from './SaveDatasetFilterDialog';
 import SaveSetDialog from './SaveSetDialog';
@@ -130,12 +132,14 @@ class App extends PureComponent {
                                                         value={loadingApp.progress}/></h2>
                         </div>}
 
+                        {dataset == null && <div><LandingPage/></div>}
                         {dataset != null && <React.Fragment>
                             <div
                                 role="tabpanel"
                                 hidden={tab !== 'embedding'}
                             >
                                 <EmbeddingCharts onGallery={this.onGallery}/>
+                                <DraggableDivider/>
                                 <div ref={this.galleryRef}>
                                     <GalleryCharts/>
                                 </div>
