@@ -34,7 +34,6 @@ import DatasetSelector from './DatasetSelector';
 import {intFormat} from './formatters';
 import {
     DEFAULT_DARK_MODE,
-    DEFAULT_INTERPOLATOR,
     DEFAULT_LABEL_FONT_SIZE,
     DEFAULT_LABEL_STROKE_WIDTH,
     DEFAULT_MARKER_OPACITY,
@@ -139,10 +138,11 @@ class AppHeader extends React.PureComponent {
         const {
             chartOptions,
             combineDatasetFilters,
-            primaryTraceKey,
+            activeFeature,
             dataset,
             embeddingLabels,
             distributionPlotOptions,
+            distributionPlotInterpolator,
             embeddings,
             searchTokens,
             datasetFilter,
@@ -172,8 +172,8 @@ class AppHeader extends React.PureComponent {
             json.camera = chartRef.scatterPlot.getCameraDef();
 
         }
-        if (primaryTraceKey != null) {
-            json.primaryTraceKey = primaryTraceKey;
+        if (activeFeature != null) {
+            json.activeFeature = activeFeature;
         }
         let jsonChartOptions = {};
 
@@ -202,18 +202,25 @@ class AppHeader extends React.PureComponent {
 
         let datasetFilterJson = {};
         for (let key in datasetFilter) {
-            let value = datasetFilter[key];
-            if (window.Array.isArray(value)) {
-                datasetFilterJson[key] = value;
+            let filterObject = datasetFilter[key];
+            if (Array.isArray(filterObject)) { // brush filter
+                const array = [];
+                filterObject.forEach(brush => {
+                    const brushJson = Object.assign({}, brush);
+                    brushJson.indices = Array.from(brush.indices);
+                    array.push(brushJson);
+                });
+                datasetFilterJson[key] = array;
+            } else if (filterObject.operation === 'in') {
+                datasetFilterJson[key] = {operation: filterObject.operation, value: filterObject.value};
             } else {
-                if (value.operation !== '' && !isNaN(value.value) && value.value != null) {
-                    datasetFilterJson[key] = {operation: value.operation, value: value.value};
+                if (filterObject.operation !== '' && !isNaN(filterObject.value) && filterObject.value != null) {
+                    datasetFilterJson[key] = {operation: filterObject.operation, value: filterObject.value};
                 }
             }
         }
         if (Object.keys(datasetFilterJson).length > 0) {
             json.datasetFilter = datasetFilterJson;
-
         }
         json.combineDatasetFilters = combineDatasetFilters;
         if (markerOpacity !== DEFAULT_MARKER_OPACITY) {
@@ -225,10 +232,11 @@ class AppHeader extends React.PureComponent {
 
         if (distributionData && distributionData.length > 0) {
             json.distributionPlotOptions = distributionPlotOptions;
+            json.distributionPlotInterpolator = Object.assign({}, distributionPlotInterpolator, {value: null});
         }
-        if (interpolator.name !== DEFAULT_INTERPOLATOR) {
-            json.colorScheme = interpolator.name;
-        }
+
+        const interpolatorJson = Object.assign({}, interpolator, {value: null});
+        json.colorScheme = interpolatorJson;
 
         if (embeddingLabels.length > 0) {
             json.embeddingLabels = embeddingLabels;
@@ -328,7 +336,7 @@ class AppHeader extends React.PureComponent {
         const datasetDetailsOpen = Boolean(this.state.datasetDetailsEl);
         const hasDatasetDetails = dataset != null && (dataset.title || dataset.description);
         const shape = dataset != null && dataset.shape != null ? dataset.shape : null;
-        const hasSelection = dataset != null && shape != null && shape[0] > 0 && !isNaN(selection.count);
+        const hasSelection = dataset != null && shape != null && shape[0] > 0 && selection.size > 0;
 
         const showNewDataset = user != null && user.importer && !loadingApp.loading;
         const showEditDeleteDataset = dataset !== null && dataset.owner && !loadingApp.loading;
@@ -369,7 +377,7 @@ class AppHeader extends React.PureComponent {
                         <Button onClick={this.handleShowDatasetDetails}><b>{dataset.name}</b></Button>}
                         {!hasDatasetDetails && <b>{dataset.name}</b>}
                         <small>&nbsp;
-                            {hasSelection && shape != null && intFormat(selection.count) + ' / '}
+                            {hasSelection && shape != null && intFormat(selection.size) + ' / '}
                             {shape != null && intFormat(shape[0]) + ' cells'}
                         </small>
 
@@ -470,36 +478,34 @@ class AppHeader extends React.PureComponent {
 
 const mapStateToProps = state => {
     return {
-        dataset: state.dataset,
-        chartOptions: state.chartOptions,
-        embeddings: state.embeddings,
-        embeddingLabels: state.embeddingLabels,
-        searchTokens: state.searchTokens,
-        primaryTraceKey: state.primaryTraceKey,
+        activeFeature: state.activeFeature,
         binSummary: state.binSummary,
         binValues: state.binValues,
+        chartOptions: state.chartOptions,
         combineDatasetFilters: state.combineDatasetFilters,
-        datasetFilter: state.datasetFilter,
-        markerOpacity: state.markerOpacity,
-        pointSize: state.pointSize,
-        unselectedMarkerOpacity: state.unselectedMarkerOpacity,
-        savedDatasetState: state.savedDatasetState,
+        dataset: state.dataset,
         datasetChoices: state.datasetChoices,
+        datasetFilter: state.datasetFilter,
         dialog: state.dialog,
         distributionData: state.distributionData,
+        distributionPlotInterpolator: state.distributionPlotInterpolator,
         email: state.email,
-
+        embeddingLabels: state.embeddingLabels,
+        embeddings: state.embeddings,
         interpolator: state.interpolator,
         jobResults: state.jobResults,
         loading: state.loading,
         loadingApp: state.loadingApp,
-
+        markerOpacity: state.markerOpacity,
         message: state.message,
-
+        pointSize: state.pointSize,
+        savedDatasetState: state.savedDatasetState,
+        searchTokens: state.searchTokens,
         selection: state.selection,
         serverInfo: state.serverInfo,
-        user: state.user,
-        tab: state.tab
+        tab: state.tab,
+        unselectedMarkerOpacity: state.unselectedMarkerOpacity,
+        user: state.user
     };
 };
 const mapDispatchToProps = (dispatch, ownProps) => {
