@@ -4,11 +4,12 @@ import ListSubheader from '@material-ui/core/ListSubheader';
 import {makeStyles, useTheme} from '@material-ui/core/styles';
 import TextField from '@material-ui/core/TextField';
 import useMediaQuery from '@material-ui/core/useMediaQuery';
-import Autocomplete, {createFilterOptions} from '@material-ui/lab/Autocomplete';
+import Autocomplete from '@material-ui/lab/Autocomplete';
 import PropTypes from 'prop-types';
 import React from 'react';
 import {VariableSizeList} from 'react-window';
 
+
 const LISTBOX_PADDING = 0; // px
 
 function renderRow(props) {
@@ -167,7 +168,7 @@ export default function AutocompleteVirtualized(props) {
         showDragIndicator(false);
     };
 
-    const filterOptions = createFilterOptions({matchFrom: 'start'});
+
     const onChipClick = props.onChipClick ? (event, option) => {
         props.onChipClick(event, option);
     } : null;
@@ -192,14 +193,54 @@ export default function AutocompleteVirtualized(props) {
     if (getOptionLabel == null) {
         getOptionLabel = props.groupBy ? (option) => option.text : (option) => option;
     }
-    let renderOption = props.renderOption;
-    if (renderOption == null) {
 
-        renderOption = props.groupBy ? (option) => <Typography title={option.text}
-                                                               noWrap>{option.text}</Typography> : (option) =>
-            <Typography
-                title={option} noWrap>{option}</Typography>;
-    }
+    const renderOption = (option, {inputValue}) => {
+        inputValue = inputValue.toLowerCase();
+        const text = getOptionLabel(option);
+        if (inputValue !== '') {
+            const index = text.toLowerCase().indexOf(inputValue);
+            if (index !== -1) {
+                const inputLength = inputValue.length;
+                const before = text.substring(0, index);
+                const match = text.substring(index, index + inputLength);
+                const after = text.substring(index + inputLength);
+                return <Typography title={text} noWrap>
+                    {before}<b>{match}</b>{after}
+                </Typography>;
+            }
+        }
+        return <Typography title={text} noWrap>{text}</Typography>;
+    };
+    // const renderOption = props.groupBy ? (option) => {
+    //  const text = getOptionLabel(option);
+    //    return <Typography title={text}  noWrap>{text}</Typography>;
+    // };
+
+    const filterOptions = (options, {inputValue}) => {
+        inputValue = inputValue.trim().toLowerCase();
+        if (inputValue === '') {
+            return options;
+        }
+        const inputLength = inputValue.length;
+        const exactMatches = [];
+        const startsWithMatches = [];
+        const containsMatches = [];
+        for (let i = 0, n = options.length; i < n; i++) {
+            const option = options[i];
+            const text = getOptionLabel(option).toLowerCase();
+            const index = text.indexOf(inputValue);
+            if (index === 0) {
+                if (text.length === inputLength) {
+                    exactMatches.push(option);
+                } else {
+                    startsWithMatches.push(option);
+                }
+            } else if (index !== -1) {
+                containsMatches.push(option);
+            }
+        }
+        return exactMatches.concat(startsWithMatches).concat(containsMatches);
+    };
     return (
         <Autocomplete
             multiple
