@@ -28,7 +28,6 @@ class CategoricalLegend extends React.PureComponent {
         };
     }
 
-
     handlePopoverClose = (e) => {
         this.setState({contextmenuEl: null, anchorEl: null});
     };
@@ -48,6 +47,7 @@ class CategoricalLegend extends React.PureComponent {
         });
         this.setState({forceUpdate: !this.state.forceUpdate});
     };
+
     handleNameChangeApply = (e) => {
         this.props.handleNameChange({
             name: this.props.name,
@@ -84,7 +84,12 @@ class CategoricalLegend extends React.PureComponent {
     handleClick = (value, index, e) => {
         if (this.props.clickEnabled) {
             e.preventDefault();
-            this.props.handleClick({name: this.props.name, value: value, shiftKey: e.shiftKey, metaKey: e.metaKey});
+            this.props.handleClick({
+                name: this.props.name,
+                value: value,
+                shiftKey: e.shiftKey,
+                metaKey: e.ctrlKey || e.metaKey
+            });
         }
     };
 
@@ -110,7 +115,7 @@ class CategoricalLegend extends React.PureComponent {
             categoricalNames
         } = this.props;
         let clickEnabled = this.props.clickEnabled;
-        const categoricalFilterValues = datasetFilter[name];
+        const categoricalFilter = datasetFilter[name];
         const selectionSummary = featureSummary[name];
         let selectedDimensionToCount = {};
         if (selectionSummary != null) {
@@ -231,7 +236,7 @@ class CategoricalLegend extends React.PureComponent {
                     <tbody>
                     {categories.map((category, i) => {
 
-                        const opacity = categoricalFilterValues == null || categoricalFilterValues.indexOf(category) !== -1 ? 1 : 0.4;
+                        const opacity = categoricalFilter == null || categoricalFilter.value.indexOf(category) !== -1 ? 1 : 0.4;
                         // const fractionUnselected = unselectedCategoryCounts != null ? unselectedCategoryCounts[i] / unselectedTotal : null;
                         // const unselectedSize = unselectedCategoryCounts == null ? 0 : fractionScale(fractionUnselected);
                         // const unselectedTitle = unselectedCategoryCounts == null ? null : intFormat(unselectedCategoryCounts[i]) + ' / ' + intFormat(unselectedTotal) + (unselectedCategoryCounts[i] > 0 ? (' ( ' + numberFormat(100 * fractionUnselected) + '%)') : '');
