@@ -1,6 +1,8 @@
 import {Typography} from '@material-ui/core';
 import Button from '@material-ui/core/Button';
 import CircularProgress from '@material-ui/core/CircularProgress';
+import Dialog from '@material-ui/core/Dialog';
+import DialogContent from '@material-ui/core/DialogContent';
 import IconButton from '@material-ui/core/IconButton';
 import InputAdornment from '@material-ui/core/InputAdornment';
 import List from '@material-ui/core/List';
@@ -12,6 +14,7 @@ import TextField from '@material-ui/core/TextField';
 import ClearIcon from '@material-ui/icons/Clear';
 import FolderOpenIcon from '@material-ui/icons/FolderOpen';
 import InfoIcon from '@material-ui/icons/Info';
+import {groupBy} from 'lodash';
 import React from 'react';
 import ReactMarkdown from 'react-markdown';
 import {connect} from 'react-redux';
@@ -21,15 +24,15 @@ export class DatasetSelector extends React.PureComponent {
 
     constructor(props) {
         super(props);
-        this.state = {anchorEl: null, searchText: '', datasetDetailsEl: null, selectedDataset: null};
+        this.state = {open: false, searchText: '', datasetDetailsEl: null, selectedDataset: null};
     }
 
     handleClick = (event) => {
-        this.setState({anchorEl: event.currentTarget, searchText: ''});
+        this.setState({open: true, searchText: ''});
     };
 
     handleClose = () => {
-        this.setState({anchorEl: null, searchText: ''});
+        this.setState({open: false, searchText: ''});
     };
 
     handleCloseDatasetDetails = (event) => {
@@ -49,7 +52,7 @@ export class DatasetSelector extends React.PureComponent {
         if (id !== selectedId) {
             this.props.onChange(id);
         }
-        this.setState({anchorEl: null, searchText: ''});
+        this.setState({open: false, searchText: ''});
     };
 
     handleClearSearchText = () => {
@@ -67,9 +70,8 @@ export class DatasetSelector extends React.PureComponent {
         if (datasetChoices.length <= 1 && selectedId != null) {
             return null;
         }
-        const {anchorEl, searchText, selectedDataset} = this.state;
+        const {open, searchText, selectedDataset} = this.state;
 
-        const open = Boolean(this.state.anchorEl);
         let filteredChoices = datasetChoices;
         const searchTextLower = this.state.searchText.toLowerCase().trim();
         if (searchTextLower != '') {
@@ -78,6 +80,9 @@ export class DatasetSelector extends React.PureComponent {
         }
         const datasetDetailsOpen = Boolean(this.state.datasetDetailsEl);
         const hasMoreInfo = selectedDataset && (selectedDataset.title || selectedDataset.description);
+        const species2Items = groupBy(filteredChoices, 'species');
+        const speciesArray = Object.keys(species2Items);
+        speciesArray.sort();
         return (
             <React.Fragment>
                 <Popover
@@ -97,9 +102,7 @@ export class DatasetSelector extends React.PureComponent {
                     <div style={{width: 500}}>
                         {selectedDataset == null &&
                         <div><CircularProgress size={20}/> Loading...</div>}
-                        {selectedDataset && <Typography component={"h6"}>
-                            {selectedDataset.name}
-                        </Typography>}
+
                         {!hasMoreInfo && <div>No description available</div>}
 
                         {selectedDataset && selectedDataset.title && <div>{selectedDataset.title}</div>}
@@ -110,55 +113,70 @@ export class DatasetSelector extends React.PureComponent {
                 <Button variant="contained" onClick={this.handleClick}
                         color={selectedId == null ? "primary" : "default"}
                         startIcon={<FolderOpenIcon/>}>Open</Button>
-                <Popover open={open}
-                         anchorEl={anchorEl}
-                         onClose={this.handleClose}
-                         anchorOrigin={{
-                             vertical: 'bottom',
-                             horizontal: 'center',
-                         }}
-                         transformOrigin={{
-                             vertical: 'top',
-                             horizontal: 'center',
-                         }}
+
+                <Dialog
+                    open={open}
+                    onClose={this.handleClose}
+                    fullWidth={true}
                 >
-                    <TextField style={{padding: 6}} type="text" placeholder={"Search"} value={searchText}
-                               onChange={this.onSearchChange}
-                               fullWidth={true}
-                               InputProps={searchText.trim() !== '' ? {
-                                   endAdornment:
-                                       <InputAdornment position="end">
-                                           <IconButton
-                                               aria-label="clear"
-                                               onClick={this.handleClearSearchText}
-                                           >
-                                               <ClearIcon/>
-                                           </IconButton>
-                                       </InputAdornment>
-                               } : null}
-                    />
-                    <List style={{width: 500}} dense disablePadding component="nav" aria-label="datasets">
-                        {filteredChoices.map(choice => {
-                            let text = choice.name;
-                            if (choice.title) {
-                                text += ' - ' + choice.title;
-                            }
-                            return <ListItem alignItems="flex-start" selected={choice.id === selectedId} key={choice.id}
-                                             button onClick={(e) => this.handleListItemClick(choice.id)}>
-                                <ListItemText
-                                    primary={text}
-                                    style={{textOverflow: 'ellipsis', overflow: 'hidden', whiteSpace: 'nowrap'}}/>
-                                <ListItemSecondaryAction>
-                                    <IconButton onClick={(e) => this.handleListItemDetailsClick(e, choice.id)}
-                                                edge="end"
-                                                aria-label="summary">
-                                        <InfoIcon/>
-                                    </IconButton>
-                                </ListItemSecondaryAction>
-                            </ListItem>;
+                    <DialogContent style={{width: 500, height: 500}}>
+                        <TextField style={{padding: 6}} type="text" placeholder={"Search"} value={searchText}
+                                   onChange={this.onSearchChange}
+                                   fullWidth={true}
+                                   InputProps={searchText.trim() !== '' ? {
+                                       endAdornment:
+                                           <InputAdornment position="end">
+                                               <IconButton
+                                                   aria-label="clear"
+                                                   onClick={this.handleClearSearchText}
+                                               >
+                                                   <ClearIcon/>
+                                               </IconButton>
+                                           </InputAdornment>
+                                   } : null}
+                        />
+
+                        {speciesArray.length === 0 && searchText.trim() !== '' &&
+                        <Typography>No Results</Typography>}
+                        {speciesArray.map(species => {
+
+                            const speciesText = species === 'null' ? 'Other' : species;
+                            const choices = species2Items[species];
+                            return <React.Fragment key={species}>
+                                <Typography component={"h2"}>{speciesText}</Typography>
+                                <List dense disablePadding component="nav">
+                                    {choices.map(choice => {
+                                        let text = choice.name;
+                                        if (choice.title) {
+                                            text += ' - ' + choice.title;
+                                        }
+                                        return <ListItem alignItems="flex-start" selected={choice.id === selectedId}
+                                                         key={choice.id}
+                                                         button
+                                                         onClick={(e) => this.handleListItemClick(choice.id)}>
+                                            <ListItemText
+                                                primary={text}
+                                                style={{
+                                                    textOverflow: 'ellipsis',
+                                                    overflow: 'hidden',
+                                                    whiteSpace: 'nowrap'
+                                                }}/>
+                                            <ListItemSecondaryAction>
+                                                <IconButton
+                                                    onClick={(e) => this.handleListItemDetailsClick(e, choice.id)}
+                                                    edge="end"
+                                                    aria-label="summary">
+                                                    <InfoIcon/>
+                                                </IconButton>
+                                            </ListItemSecondaryAction>
+                                        </ListItem>;
+                                    })}
+                                </List></React.Fragment>;
                         })}
-                    </List>
-                </Popover>
+                    </DialogContent>
+
+                </Dialog>
+
             </React.Fragment>
         );
     }
