@@ -1,4 +1,5 @@
 import {InputLabel, MenuItem, Select} from '@material-ui/core';
+import Box from '@material-ui/core/Box';
 import FormControl from '@material-ui/core/FormControl';
 import Input from '@material-ui/core/Input';
 import withStyles from '@material-ui/core/styles/withStyles';
@@ -9,7 +10,12 @@ import DotPlotCanvas from './DotPlotCanvas';
 import {EditableColorScheme} from './EditableColorScheme';
 import {EditableSizeLegend} from './EditableSizeLegend';
 import {boxplotStats, density, nrd0} from './kde';
-import {createColorScale} from './util';
+import {
+    createColorScale,
+    INTERPOLATOR_SCALING_MIN_MAX_CATEGORY,
+    INTERPOLATOR_SCALING_MIN_MAX_FEATURE,
+    INTERPOLATOR_SCALING_NONE
+} from './util';
 import ViolinPlot from './ViolinPlot';
 
 const styles = theme => ({
@@ -42,6 +48,7 @@ function updateNames(data, categoricalNames) {
 function reshapeData(data, distributionPlotOptions) {
     // create 2-d array with categories along rows and features along columns
     let categoryToFeatures = {};
+
     data.forEach(item => {
         let features = categoryToFeatures[item.name];
         if (features == null) {
@@ -82,22 +89,23 @@ function reshapeData(data, distributionPlotOptions) {
     }
     let data2d = [];
     for (let i = 0; i < categories.length; i++) {
-        let category = categories[i];
-        data2d.push(categoryToFeatures[category]);
+        const category = categories[i];
+        const features = categoryToFeatures[category];
+        data2d.push(features);
     }
     return data2d;
 }
 
 function getMeanAndPercentRange(result) {
-    let percentRange = [Number.MAX_VALUE, -Number.MAX_VALUE];
+    // let percentRange = [Number.MAX_VALUE, -Number.MAX_VALUE];
     let meanRange = [Number.MAX_VALUE, -Number.MAX_VALUE];
     result.forEach(feature => {
-        percentRange[0] = Math.min(feature.percentExpressed, percentRange[0]);
-        percentRange[1] = Math.max(feature.percentExpressed, percentRange[1]);
+        // percentRange[0] = Math.min(feature.percentExpressed, percentRange[0]);
+        // percentRange[1] = Math.max(feature.percentExpressed, percentRange[1]);
         meanRange[0] = Math.min(feature.mean, meanRange[0]);
         meanRange[1] = Math.max(feature.mean, meanRange[1]);
     });
-    return {mean: meanRange, percent: percentRange};
+    return {mean: meanRange, percent: [0, 100]};
 }
 
 class DistributionGroup extends React.PureComponent {
@@ -121,7 +129,7 @@ class DistributionGroup extends React.PureComponent {
             return null;
         }
         const meanAndPercentRange = getMeanAndPercentRange(distributionData);
-        const meanRange = meanAndPercentRange.mean;
+        const meanRange = interpolator.scale !== INTERPOLATOR_SCALING_NONE ? [0, 1] : meanAndPercentRange.mean;
         const percentRange = meanAndPercentRange.percent;
         if (selectedData != null && selectedData.length > 0) {
             const selectedMeanAndPercentRange = getMeanAndPercentRange(selectedData);
@@ -130,22 +138,6 @@ class DistributionGroup extends React.PureComponent {
             percentRange[0] = Math.min(percentRange[0], selectedMeanAndPercentRange.percent[0]);
             percentRange[1] = Math.max(percentRange[1], selectedMeanAndPercentRange.percent[1]);
         }
-        if (meanRange[0] === meanRange[1]) {
-            meanRange[1]++;
-        }
-        if (percentRange[0] === percentRange[1]) {
-            percentRange[0] = 0;
-            percentRange[1] = 100;
-        }
-        if (meanRange[0] > 0) {
-            meanRange[0] = 0;
-        }
-        if (percentRange[0] > 0) {
-            percentRange[0] = 0;
-        }
-        if (percentRange[1] > 100) {
-            percentRange[1] = 100;
-        }
 
         if (distributionPlotOptions.min != null && !isNaN(distributionPlotOptions.min)) {
             meanRange[0] = distributionPlotOptions.min;
@@ -182,8 +174,6 @@ class DistributionGroup extends React.PureComponent {
         const minRadius = 1;
         const colorScale = createColorScale(interpolator).domain(meanRange);
         const sizeScale = scaleLinear().domain(percentRange).range([minRadius, maxRadius]).clamp(true);
-
-
         updateNames(distributionData, categoricalNames);
         if (selectedData) {
             updateNames(selectedData, categoricalNames);
@@ -216,12 +206,12 @@ class DistributionGroup extends React.PureComponent {
         }
 
         const sortChoices = [distributionData[0].dimension].concat(features);
-
         return (
-            <React.Fragment>
+            <Box color="text.primary">
                 {chartType !== 'violin' && <DotPlotCanvas
                     categoryColorScales={categoryColorScales}
                     colorScale={colorScale}
+                    interpolator={interpolator}
                     sizeScale={sizeScale}
                     textColor={textColor}
                     drawCircles={chartType === 'dotplot'}
@@ -237,6 +227,7 @@ class DistributionGroup extends React.PureComponent {
                     <DotPlotCanvas
                         categoryColorScales={categoryColorScales}
                         colorScale={colorScale}
+                        interpolator={interpolator}
                         sizeScale={sizeScale}
                         subtitle="selection"
                         textColor={textColor}
@@ -253,10 +244,28 @@ class DistributionGroup extends React.PureComponent {
                 {chartType !== 'violin' &&
                 <EditableColorScheme colorScale={colorScale}
                                      textColor={textColor}
+                                     domain={colorScale.domain()}
                                      interpolator={interpolator}
                                      onOptions={this.props.onDistributionPlotOptions}
                                      onInterpolator={this.props.handleInterpolator}/>}
+
+                {chartType !== 'violin' && <FormControl className={this.props.classes.formControl}>
+                    <InputLabel shrink={true}>Standardize</InputLabel>
+                    <Select
+                        input={<Input size={"small"}/>}
+                        onChange={event => this.props.onColorScalingChange(event.target.value)}
+                        value={interpolator.scale}
+                    >
+                        <MenuItem value={"none"} divider>(None)</MenuItem>
+                        <MenuItem title={"Standardize features between 0 and 1"}
+                                  value={INTERPOLATOR_SCALING_MIN_MAX_FEATURE}>Feature</MenuItem>
+                        <MenuItem title={"Standardize groups between 0 and 1"}
+                                  value={INTERPOLATOR_SCALING_MIN_MAX_CATEGORY}>Category</MenuItem>
+
+                    </Select>
+                </FormControl>}
                 {chartType === 'dotplot' && <div style={{paddingTop: 16}}>
+                    <InputLabel shrink={true}>Size</InputLabel>
                     <EditableSizeLegend sizeScale={sizeScale} textColor={textColor}
                                         onOptions={this.props.onDistributionPlotOptions} showReversed={false}/>
                 </div>}
@@ -274,8 +283,7 @@ class DistributionGroup extends React.PureComponent {
                         ))}
                     </Select>
                 </FormControl>
-
-            </React.Fragment>
+            </Box>
         );
     }
 
