@@ -4,39 +4,40 @@ import Menu from '@material-ui/core/Menu';
 import MenuItem from '@material-ui/core/MenuItem';
 import Typography from '@material-ui/core/Typography';
 import PhotoCameraIcon from '@material-ui/icons/PhotoCamera';
+import {cumsum} from 'd3-array';
+import {scaleLinear} from 'd3-scale';
 import React from 'react';
 import {CANVAS_FONT, SVG_FONT} from './ChartUtil';
 import {drawColorScheme} from './ColorSchemeLegend';
 import {numberFormat, numberFormat2f} from './formatters';
 import {drawSizeLegend} from './SizeLegend';
-import {stripTrailingZeros} from './util';
+import {INTERPOLATOR_SCALING_MIN_MAX_CATEGORY, INTERPOLATOR_SCALING_MIN_MAX_FEATURE, stripTrailingZeros} from './util';
 
 export const CHIP_SIZE = 12;
 
 export function getNameWidth(array2d, context) {
-    let offsets = [];
+    let endCoordinates = [];
     let ncategories = 0;
     if (array2d[0].length > 0) {
         ncategories = array2d[0][0].name.length;
         for (let i = 0; i < array2d[0][0].name.length; i++) {
-            offsets.push(0);
+            endCoordinates.push(0);
         }
     }
     array2d.forEach(array => {
         let name = array[0].name;
         for (let i = 0; i < ncategories; i++) {
-            offsets[i] = Math.max(offsets[i], context.measureText(name[i]).width);
+            endCoordinates[i] = Math.max(endCoordinates[i], context.measureText(name[i]).width);
         }
     });
-    for (let i = 0; i < offsets.length; i++) {
-        // 4px, chip, 2px, text
-        offsets[i] += 6;
-        offsets[i] += CHIP_SIZE;
+    for (let i = 0; i < endCoordinates.length; i++) {
+        // chip, 2px, text, 4px, ...
+        endCoordinates[i] += 6;
+        endCoordinates[i] += CHIP_SIZE;
     }
-    offsets[offsets.length - 1] += 4;
-    let xTotal = 0;
-    offsets.forEach(val => xTotal += val);
-    return {offsets: offsets, sum: xTotal};
+    endCoordinates = cumsum(endCoordinates);
+    endCoordinates[endCoordinates.length - 1] += 4;
+    return {endCoordinates: endCoordinates, sum: endCoordinates[endCoordinates.length - 1]};
 }
 
 
@@ -113,34 +114,76 @@ export default class DotPlotCanvas extends React.PureComponent {
     drawContext(context, size) {
         const data2d = this.props.data;
         const colorScale = this.props.colorScale;
+        const interpolator = this.props.interpolator;
         const categoryColorScales = this.props.categoryColorScales;
         const sizeScale = this.props.sizeScale;
         const drawCircles = this.props.drawCircles;
         const textColor = this.props.textColor;
         const maxRadius = sizeScale.range()[1];
-        let diameter = maxRadius * 2;
+        const diameter = maxRadius * 2;
         // context.strokeStyle = gridColor;
         // context.lineWidth = gridThickness;
-
-        data2d.forEach((array, j) => { // each category
-            const ypix = j * diameter + (drawCircles ? maxRadius : 0);
-            for (let i = 0; i < array.length; i++) { // each feature
-                const mean = array[i].mean;
+        const valueScale = interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_FEATURE || interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_CATEGORY ? scaleLinear().range([0, 1]) : null;
+        const nfeatures = data2d.length > 0 ? data2d[0].length : 0;
+        const ncategories = data2d.length;
+        let domains = null;
+        if (interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_FEATURE) {
+            domains = [];
+            for (let featureIndex = 0; featureIndex < nfeatures; featureIndex++) {
+                let min = Number.MAX_VALUE;
+                let max = -Number.MAX_VALUE;
+                for (let categoryIndex = 0; categoryIndex < ncategories; categoryIndex++) {
+                    const array = data2d[categoryIndex];
+                    const mean = array[featureIndex].mean;
+                    min = Math.min(min, mean);
+                    max = Math.max(max, mean);
+                }
+                domains.push([min, max]);
+            }
+        } else if (interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_CATEGORY) {
+            domains = [];
+            for (let categoryIndex = 0; categoryIndex < ncategories; categoryIndex++) {
+                let min = Number.MAX_VALUE;
+                let max = -Number.MAX_VALUE;
+                for (let featureIndex = 0; featureIndex < nfeatures; featureIndex++) {
+                    const array = data2d[categoryIndex];
+                    const mean = array[featureIndex].mean;
+                    min = Math.min(min, mean);
+                    max = Math.max(max, mean);
+                }
+                domains.push([min, max]);
+            }
+        }
+        for (let featureIndex = 0; featureIndex < nfeatures; featureIndex++) { // each feature
+            if (interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_FEATURE) {
+                valueScale.domain(domains[featureIndex]);
+            }
+            for (let categoryIndex = 0; categoryIndex < ncategories; categoryIndex++) {
+                if (interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_CATEGORY) {
+                    valueScale.domain(domains[categoryIndex]);
+                }
+                const item = data2d[categoryIndex][featureIndex];
+                let mean = item.mean;
+                const ypix = categoryIndex * diameter + (drawCircles ? maxRadius : 0);
+                if (valueScale) {
+                    mean = valueScale(mean);
+                }
                 const color = colorScale(mean);
                 context.fillStyle = color;
                 context.beginPath();
                 if (drawCircles) {
-                    const xpix = i * diameter + maxRadius + size.x;
-                    const frac = array[i].percentExpressed;
+                    const xpix = featureIndex * diameter + maxRadius + size.x;
+                    const frac = item.percentExpressed;
                     context.arc(xpix, ypix, sizeScale(frac), 0, 2 * Math.PI);
                 } else {
-                    const xpix = i * diameter + size.x;
+                    const xpix = featureIndex * diameter + size.x;
                     context.rect(xpix, ypix, diameter, diameter);
                 }
                 context.fill();
-                // context.stroke();
             }
-        });
+            // context.stroke();
+        }
+
 
         context.textAlign = 'left';
         context.textBaseline = 'middle';
@@ -149,19 +192,15 @@ export default class DotPlotCanvas extends React.PureComponent {
             let name = array[0].name;
             const pix = i * diameter + maxRadius;
             for (let j = 0; j < name.length; j++) {
-                // 4px, chip, 2px, text
-                let xpixstart = size.xoffsets[j - 1] || 0;
-                if (xpixstart > 0) {
-                    xpixstart += 4;
-                }
+                const chipStartCoord = j === 0 ? 0 : size.endCoordinates[j - 1];
                 const categoryColorScale = categoryColorScales[j];
                 context.fillStyle = categoryColorScale(array[0].categories[j]);
                 context.beginPath();
-                context.rect(xpixstart, pix - maxRadius / 2 - 3, CHIP_SIZE, CHIP_SIZE);
+                context.rect(chipStartCoord, pix - maxRadius / 2 - 3, CHIP_SIZE, CHIP_SIZE);
                 context.fill();
                 context.stroke();
                 context.fillStyle = textColor;
-                context.fillText(name[j], xpixstart + 2 + CHIP_SIZE, pix);
+                context.fillText(name[j], chipStartCoord + 2 + CHIP_SIZE, pix);
             }
         });
         context.textAlign = 'right';
@@ -201,11 +240,17 @@ export default class DotPlotCanvas extends React.PureComponent {
         const diameter = maxRadius * 2;
         const height = array2d.length * diameter + 4;
         const width = array2d[0].length * diameter + 4;
-        return {xoffsets: nameWidth.offsets, x: nameWidth.sum, y: maxFeatureWidth, width: width, height: height};
+        return {
+            endCoordinates: nameWidth.endCoordinates,
+            x: nameWidth.sum,
+            y: maxFeatureWidth,
+            width: width,
+            height: height
+        };
     }
 
     update() {
-        const canvas = document.createElement('canvas');
+        const canvas = this.canvas == null ? document.createElement('canvas') : this.canvas;
         const context = canvas.getContext('2d');
         context.font = CANVAS_FONT;
         this.size = this.getSize(context);
@@ -262,8 +307,9 @@ export default class DotPlotCanvas extends React.PureComponent {
         drawColorScheme(context, this.props.colorScale, textColor);
         context.translate(-10, (colorScaleHeight + 4));
 
-        drawSizeLegend(context, this.props.sizeScale, 3, 150, 20, textColor);
-
+        if (this.props.drawCircles) {
+            drawSizeLegend(context, this.props.sizeScale, 3, 150, 20, textColor);
+        }
         if (format === 'svg') {
             let svg = context.getSerializedSvg();
             // let prefix = [];
