@@ -19,7 +19,7 @@ import ColorSchemeLegendWrapper from './ColorSchemeLegendWrapper';
 import ImageChart from './ImageChart';
 import MetaEmbedding from './MetaEmbedding';
 import ScatterChartThree from './ScatterChartThree';
-import {splitSearchTokens} from './util';
+import {splitSearchTokens, TRACE_TYPE_META_IMAGE} from './util';
 
 class EmbeddingChart extends React.PureComponent {
 
@@ -34,7 +34,7 @@ class EmbeddingChart extends React.PureComponent {
         }
     }
 
-    handleExpandClick = (e) => {
+    handleToggleLegend = (e) => {
         e.preventDefault();
         this.setState({showDetails: !this.state.showDetails});
     };
@@ -50,10 +50,8 @@ class EmbeddingChart extends React.PureComponent {
             featureSummary,
             globalFeatureSummary,
             markerOpacity,
-            nObsSelected,
             onChartOptions,
             onColorChange,
-            onDeselect,
             onDimensionFilterUpdated,
             onDomain,
             onGallery,
@@ -69,25 +67,29 @@ class EmbeddingChart extends React.PureComponent {
             unselectedMarkerOpacity
         } = this.props;
 
+        const nObsSelected = selection.size;
         const activeEmbeddingLabels = splitSearchTokens(searchTokens).obsCat.filter(item => embeddingLabels.indexOf(item) !== -1);
         const displayName = traceInfo.name === '__count' ? '' : traceInfo.name;
 
         return (
             <div style={{position: 'relative'}}>
                 <Box color="text.primary" style={{
-                    marginTop: '3.2px',
+                    marginTop: 3.2,
                     position: 'absolute',
                     textAlign: 'right',
+                    overflow: 'hidden',
+                    whiteSpace: 'nowrap',
+                    textOverflow: 'ellipsis',
+                    maxWidth: 300,
                     right: 8,
                     zIndex: 1000
                 }}>
-                    {displayName !== '' ? <Tooltip title={"Embedding: " + traceInfo.embedding.name}>
-                        <Link onClick={this.handleExpandClick}>
-                            <Typography
-                                color="textPrimary" style={{marginRight: 14}}
-                                component={"h4"}>{displayName} {!traceInfo.continuous ?
-                                <small>({globalFeatureSummary[traceInfo.name].categories.length})</small> : null}</Typography></Link>
-                    </Tooltip> : null}
+                    {displayName !== '' &&
+                    <Tooltip title={"Embedding: " + traceInfo.embedding.name}><Link onClick={this.handleToggleLegend}>
+                        <Typography
+                            color="textPrimary" style={{marginRight: 14}}
+                            component={"h4"}>{displayName}</Typography></Link></Tooltip>
+                    }
 
                     {traceInfo.continuous ?
                         <ColorSchemeLegendWrapper
@@ -101,7 +103,7 @@ class EmbeddingChart extends React.PureComponent {
                             }}
                             handleUpdate={onMeasureFilterUpdated}
                             datasetFilter={datasetFilter}
-                            scale={traceInfo.colorScale}
+                            colorScale={traceInfo.colorScale}
                             featureSummary={featureSummary}
                             globalFeatureSummary={globalFeatureSummary}
                             nObs={shape[0]}
@@ -121,7 +123,7 @@ class EmbeddingChart extends React.PureComponent {
                             categoricalNames={categoricalNames}
                             name={traceInfo.name}
                             scale={traceInfo.colorScale}
-                            maxHeight={300}
+                            maxHeight={primaryChartSize.height - 40}
                             clickEnabled={true}
                             nObs={shape[0]}
                             nObsSelected={nObsSelected}
@@ -140,7 +142,6 @@ class EmbeddingChart extends React.PureComponent {
                                    chartOptions={chartOptions}
                                    categoricalNames={categoricalNames}
                                    selection={selection}
-                                   onDeselect={onDeselect}
                                    onSelected={onSelect}
                                    pointSize={pointSize}
                                    markerOpacity={markerOpacity}
@@ -150,16 +151,18 @@ class EmbeddingChart extends React.PureComponent {
 
                 />}
 
-                {traceInfo.type === 'meta_image' &&
+                {traceInfo.type === TRACE_TYPE_META_IMAGE &&
                 <MetaEmbedding traceInfo={traceInfo}
                                cachedData={cachedData}
                                chartSize={primaryChartSize}
                                setChartOptions={onChartOptions}
                                chartOptions={chartOptions}
                                dataset={dataset}
+                               selection={selection}
                                categoricalNames={categoricalNames}
                                markerOpacity={markerOpacity}
                                onGallery={onGallery}
+                               onSelected={onSelect}
 
                 />}
                 {traceInfo.type === 'image' && <ImageChart
@@ -176,12 +179,9 @@ class EmbeddingChart extends React.PureComponent {
                     onInitialized={this.onInitialized}
                     markerOpacity={markerOpacity}
                     unselectedMarkerOpacity={unselectedMarkerOpacity}
-                    onDeselect={onDeselect}
                     onSelected={onSelect}
                     onGallery={onGallery}
                 />}
-
-
             </div>);
 
     }
@@ -195,15 +195,13 @@ const mapStateToProps = state => {
         dataset: state.dataset,
         datasetFilter: state.datasetFilter,
         embeddingChartSize: state.embeddingChartSize,
-        embeddingData: state.embeddingData,
         embeddingLabels: state.embeddingLabels,
         featureSummary: state.featureSummary,
         globalFeatureSummary: state.globalFeatureSummary,
         markerOpacity: state.markerOpacity,
-        nObsSelected: state.selection.count,
+        selection: state.selection,
         pointSize: state.pointSize,
         primaryChartSize: state.primaryChartSize,
-        primaryTraceKey: state.primaryTraceKey,
         shape: state.dataset.shape,
         searchTokens: state.searchTokens,
         unselectedMarkerOpacity: state.unselectedMarkerOpacity,
@@ -231,10 +229,7 @@ const mapDispatchToProps = dispatch => {
         },
         onSelect: (e) => {
             dispatch(handleBrushFilterUpdated(e));
-        },
-        onDeselect: (e) => {
-            dispatch(handleBrushFilterUpdated(e));
-        },
+        }
 
     };
 };
