@@ -1,11 +1,8 @@
-import {Tooltip} from '@material-ui/core';
-import Typography from '@material-ui/core/Typography';
-import HelpOutlineIcon from '@material-ui/icons/HelpOutline';
 import React from 'react';
 
 import {connect} from 'react-redux';
 import {sortableContainer, sortableElement} from 'react-sortable-hoc';
-import {getTraceKey, setEmbeddingData, setPrimaryTraceKey} from './actions';
+import {getTraceKey, setActiveFeature, setEmbeddingData} from './actions';
 import GalleryImage from './GalleryImage';
 import {createScatterPlot} from './ThreeUtil';
 import {splitSearchTokens} from './util';
@@ -19,18 +16,21 @@ function createContainer(chartSize) {
     return containerElement;
 }
 
+
 class GalleryCharts extends React.PureComponent {
     constructor(props) {
         super(props);
         this.containerElement = createContainer(this.props.chartSize);
         document.body.appendChild(this.containerElement);
         this.scatterPlot = createScatterPlot(this.containerElement, window.ApplePaySession != null, false, false);
-        this.emptySet = new Set();
-
     }
 
     onChartSelected = (traceInfo) => {
-        this.props.handlePrimaryTraceKey(getTraceKey(traceInfo));
+        this.props.handleActiveFeature({
+            name: traceInfo.name,
+            type: traceInfo.featureType,
+            embeddingKey: getTraceKey(traceInfo)
+        });
         window.scrollTo(0, 0);
     };
 
@@ -42,7 +42,7 @@ class GalleryCharts extends React.PureComponent {
 
 
     render() {
-        let {
+        const {
             cachedData,
             categoricalNames,
             chartSize,
@@ -62,52 +62,43 @@ class GalleryCharts extends React.PureComponent {
             document.body.appendChild(this.containerElement);
             this.scatterPlot = createScatterPlot(this.containerElement, window.ApplePaySession, false, false);
         }
-        let galleryTraces = embeddingData.filter(traceInfo => traceInfo.active);
-
-        for (let i = 0; i < galleryTraces.length; i++) {
-            if (galleryTraces[i].sortIndex == null) {
-                galleryTraces[i].sortIndex = i;
-            }
-        }
-        galleryTraces.sort((a, b) => a.sortIndex - b.sortIndex);
+        const galleryTraces = embeddingData.filter(traceInfo => traceInfo.active);
         const obsCat = splitSearchTokens(searchTokens).obsCat.filter(item => embeddingLabels.indexOf(item) !== -1);
         // const DragHandle = sortableHandle(() => <span>::</span>);
-
-        const SortableItem = sortableElement(({traceInfo}) => <GalleryImage
-            traceInfo={traceInfo}
+        const SortableItem = sortableElement(({trace}) => <GalleryImage
+            traceInfo={trace}
             obsCat={obsCat}
             cachedData={cachedData}
             scatterPlot={this.scatterPlot}
             markerOpacity={markerOpacity}
             chartOptions={chartOptions}
             pointSize={pointSize}
+            primaryChartSize={primaryChartSize}
             chartSize={chartSize}
             categoricalNames={categoricalNames}
-            primaryChartSize={primaryChartSize}
             unselectedMarkerOpacity={unselectedMarkerOpacity}
             selection={selection}
             containerElement={this.containerElement}
             onSelect={this.onChartSelected}
-            key={getTraceKey(traceInfo)}/>);
+            key={getTraceKey(trace)}/>);
 
         const SortableList = sortableContainer(({items}) => {
             return (
-                <ul style={{padding: 0}}>
-                    {items.map((traceInfo, index) => (
-                        <SortableItem key={getTraceKey(traceInfo)} index={index} traceInfo={traceInfo}/>
+                <ul style={{padding: 0, marginTop: 4, marginBottom: 0}}>
+                    {items.map((trace, index) => (
+                        <SortableItem key={getTraceKey(trace)} index={index} trace={trace}/>
                     ))}
                 </ul>
             );
         });
 
         return (
-            <React.Fragment><Typography variant="subtitle1">Gallery<Tooltip
-                title="Drag gallery charts to reorder. Click chart to set primary view."><HelpOutlineIcon
-                style={{verticalAlign: 'text-bottom'}}/></Tooltip></Typography>
+            <React.Fragment>
                 <SortableList
                     distance={2}
                     axis="xy" items={galleryTraces}
-                    onSortEnd={(e) => this.onSortEnd(galleryTraces, e)}/></React.Fragment>);
+                    onSortEnd={(e) => this.onSortEnd(galleryTraces, e)}/></React.Fragment>
+        );
     }
 }
 
@@ -122,7 +113,6 @@ const mapStateToProps = state => {
         markerOpacity: state.markerOpacity,
         pointSize: state.pointSize,
         primaryChartSize: state.primaryChartSize,
-        primaryTraceKey: state.primaryTraceKey,
         searchTokens: state.searchTokens,
         selection: state.selection,
         unselectedMarkerOpacity: state.unselectedMarkerOpacity,
@@ -130,8 +120,8 @@ const mapStateToProps = state => {
 };
 const mapDispatchToProps = dispatch => {
     return {
-        handlePrimaryTraceKey: (value) => {
-            dispatch(setPrimaryTraceKey(value));
+        handleActiveFeature: (value) => {
+            dispatch(setActiveFeature(value));
         },
         handleEmbeddingData: (value) => {
             dispatch(setEmbeddingData(value));
