@@ -67,13 +67,11 @@ function drawSpots(context, zoom, traceInfo, selection, markerOpacity, unselecte
     const indices = traceInfo.indices;
     if (!isSelectionEmpty) { // draw unselected cells 1st
         context.globalAlpha = unselectedMarkerOpacity;
-
         for (let i = 0; i < traceInfo.x.length; i++) {
             let index = indices[i];
             let x = traceInfo.x[index];
             let y = traceInfo.y[index];
-            const isSelected = selection.has(index);
-            if (!isSelected) {
+            if (!selection.has(index)) {
                 context.fillStyle = traceInfo.colors[index];
                 context.beginPath();
                 context.arc(x, y, spotRadius, 0, Math.PI * 2, true);
@@ -85,8 +83,7 @@ function drawSpots(context, zoom, traceInfo, selection, markerOpacity, unselecte
             let index = indices[i];
             let x = traceInfo.x[index];
             let y = traceInfo.y[index];
-            const isSelected = selection.has(index);
-            if (isSelected) {
+            if (selection.has(index)) {
                 context.fillStyle = traceInfo.colors[index];
                 context.beginPath();
                 context.arc(x, y, spotRadius, 0, Math.PI * 2, true);
@@ -135,6 +132,7 @@ class ImageChart extends React.PureComponent {
     constructor(props) {
         super(props);
         this.id = uniqueId('cirro-image');
+        this.editSelection = false;
         this.tooltipElementRef = React.createRef();
         this.state = {loading: false};
     }
@@ -334,7 +332,7 @@ class ImageChart extends React.PureComponent {
         this.viewer.addHandler('canvas-press', function (event) {
             if (_this.props.chartOptions.dragmode === 'lasso' || _this.props.chartOptions.dragmode === 'select') {
                 event.preventDefaultAction = true;
-
+                _this.editSelection = event.metaKey || event.ctrlKey;
                 let webPoint = event.position;
                 let viewportPoint = viewer.viewport.pointFromPixel(webPoint);
                 let imagePoint = viewer.world.getItemAt(0).viewportToImageCoordinates(viewportPoint, true);
@@ -360,25 +358,25 @@ class ImageChart extends React.PureComponent {
         this.viewer.addHandler('canvas-release', function (event) {
             if (_this.props.chartOptions.dragmode === 'lasso') {
                 event.preventDefaultAction = true;
-                const points = _this.findPointsInPolygon(lassoPathArray);
+                const indices = new Set(_this.findPointsInPolygon(lassoPathArray));
                 lassoPathArray = [];
                 lassoPath.setAttribute('d', '');
                 _this.props.onSelected({
                     name: getEmbeddingKey(_this.props.traceInfo.embedding),
-                    clear: !_this.props.chartOptions.editSelection,
-                    value: {basis: _this.props.traceInfo.embedding, points: points}
+                    clear: !_this.editSelection,
+                    value: {basis: _this.props.traceInfo.embedding, indices: indices}
                 });
             } else if (_this.props.chartOptions.dragmode === 'select') {
                 event.preventDefaultAction = true;
-                const points = _this.findPointsInRectangle(rectElement);
+                const indices = new Set(_this.findPointsInRectangle(rectElement));
                 rectElement.removeAttribute('x');
                 rectElement.removeAttribute('y');
                 rectElement.removeAttribute('width');
                 rectElement.removeAttribute('height');
                 _this.props.onSelected({
                     name: getEmbeddingKey(_this.props.traceInfo.embedding),
-                    clear: !_this.props.chartOptions.editSelection,
-                    value: {basis: _this.props.traceInfo.embedding, points: points}
+                    clear: !_this.editSelection,
+                    value: {basis: _this.props.traceInfo.embedding, indices: indices}
                 });
             }
         });
@@ -390,7 +388,7 @@ class ImageChart extends React.PureComponent {
         //         let imagePoint = viewer.world.getItemAt(0).viewportToImageCoordinates(viewportPoint, true);
         //         const point = _this.findPointIndex(imagePoint.x, imagePoint.y);
         //         if (point === -1) {
-        //             //   this.props.onDeselect({name: getEmbeddingKey(traceInfo.embedding)});
+        //             //   this.props.onSelected({name: getEmbeddingKey(traceInfo.embedding)});
         //         } else {
         //             _this.props.onSelected({
         //                 name: getEmbeddingKey(_this.props.traceInfo.embedding),
@@ -449,10 +447,10 @@ class ImageChart extends React.PureComponent {
         saveImage(traceInfo, {width: img.width, height: img.height}, bind(this.drawContext, this), format);
     };
 
-    onEditSelection = () => {
-        this.props.chartOptions.editSelection = !this.props.chartOptions.editSelection;
-        this.props.setChartOptions(this.props.chartOptions);
-    };
+    // onEditSelection = () => {
+    //     this.props.chartOptions.editSelection = !this.props.chartOptions.editSelection;
+    //     this.props.setChartOptions(this.props.chartOptions);
+    // };
 
 
     onZoomIn = () => {
@@ -481,7 +479,7 @@ class ImageChart extends React.PureComponent {
             <div className={this.props.classes.root}>
                 <ChartToolbar
                     dragmode={this.props.chartOptions.dragmode}
-                    editSelection={this.props.chartOptions.editSelection}
+                    // editSelection={this.props.chartOptions.editSelection}
                     onGallery={this.props.onGallery}
                     animating={false}
                     onZoomIn={this.onZoomIn}
@@ -490,7 +488,7 @@ class ImageChart extends React.PureComponent {
                     onHome={this.onHome}
                     onSaveImage={this.onSaveImage}
                     onDragMode={this.onDragMode}
-                    onEditSelection={this.onEditSelection}
+                    // onEditSelection={this.onEditSelection}
                 >
                 </ChartToolbar>
                 <Typography color="textPrimary" ref={this.tooltipElementRef} style={{
