@@ -1,7 +1,9 @@
 import {
     Checkbox,
     Dialog,
+    DialogActions,
     DialogContent,
+    DialogContentText,
     DialogTitle,
     Table,
     TableBody,
@@ -11,20 +13,29 @@ import {
 } from '@material-ui/core';
 import Box from '@material-ui/core/Box';
 import Button from '@material-ui/core/Button';
-import List from '@material-ui/core/List';
-import ListItem from '@material-ui/core/ListItem';
-import ListItemText from '@material-ui/core/ListItemText';
+import Divider from '@material-ui/core/Divider';
+import Grid from '@material-ui/core/Grid';
+import IconButton from '@material-ui/core/IconButton';
 import withStyles from '@material-ui/core/styles/withStyles';
 import Typography from '@material-ui/core/Typography';
+import DeleteIcon from '@material-ui/icons/Delete';
 import {scaleLinear} from 'd3-scale';
 import {find} from 'lodash';
 import natsort from 'natsort';
 import React from 'react';
 import {connect} from 'react-redux';
-import {setJobResult, setSearchTokensDirectly, setTab} from './actions';
+import {deleteJobResult, setJobResult, setSearchTokensDirectly, setTab} from './actions';
 import {createFilterFunction} from './dataset_filter';
 import {intFormat, numberFormat2f} from './formatters';
-import {createColorScale, getInterpolator, X_SEARCH_TOKEN} from './util';
+import {
+    createColorScale,
+    FEATURE_TYPE,
+    getInterpolator,
+    INTERPOLATOR_SCALING_MIN_MAX_CATEGORY,
+    INTERPOLATOR_SCALING_MIN_MAX_FEATURE,
+    INTERPOLATOR_SCALING_NONE,
+    scaleConstantRange
+} from './util';
 
 const styles = theme => ({
     dot: {
@@ -32,22 +43,31 @@ const styles = theme => ({
         display: 'inlineBlock',
         border: '1px solid lightgray'
     },
-    visuallyHidden: {
-        border: 0,
-        clip: 'rect(0 0 0 0)',
-        height: 1,
-        margin: -1,
-        overflow: 'hidden',
-        padding: 0,
-        position: 'absolute',
-        top: 20,
-        width: 1,
+    toolbar: {
+        '& hr': {
+            margin: theme.spacing(0, 0.5),
+        }
     },
     table: {
         borderCollapse: 'collapse',
         position: 'relative',
         width: 'unset'
     },
+    tr: {
+        cursor: 'pointer',
+    },
+    deleteTr: {
+        cursor: 'pointer',
+        '& span': {
+            display: 'none',
+        },
+        '&:hover span': {
+            display: 'block',
+            position: 'absolute',
+            right: 0,
+            top: 0
+        }
+    },
     rotateHeader: {
         top: 0,
         padding: 1,
@@ -95,20 +115,21 @@ const DEFAULT_DE_INTERPOLATOR = 'RdBu';
 
 
 export function updateJob(jobResult) {
-    if (jobResult.options == null) {
+    if (jobResult.options === undefined) {
         jobResult.options = {};
     }
-    if (jobResult.interpolator == null) {
+    if (jobResult.interpolator === undefined) {
         jobResult.interpolator = {
             name: DEFAULT_DE_INTERPOLATOR,
             value: getInterpolator(DEFAULT_DE_INTERPOLATOR),
-            reversed: true
+            reversed: true,
+            scale: INTERPOLATOR_SCALING_NONE
         };
     }
     const groups = jobResult.groups;
     const data = jobResult.data;
 
-    if (jobResult.columns == null) {
+    if (jobResult.columns === undefined) {
         const sorter = natsort({insensitive: true});
         const indices = new Array(groups.length);
         for (let i = 0, n = jobResult.groups.length; i < n; i++) {
@@ -120,7 +141,7 @@ export function updateJob(jobResult) {
         });
     }
 
-    if (jobResult.rowFilters == null) {
+    if (jobResult.rowFilters === undefined) {
         const filters = [];
         jobResult.fields.forEach(field => {
             filters.push([field, '>', NaN, '']);
@@ -128,11 +149,11 @@ export function updateJob(jobResult) {
 
         jobResult.rowFilters = filters;
     }
-    if (jobResult.ntop == null) {
+    if (jobResult.ntop === undefined) {
         jobResult.ntop = 10;
         jobResult.ntopUI = 10;
     }
-    if (jobResult.sortedRows == null) {
+    if (jobResult.sortedRows === undefined) {
         const indices = new Array(data.length);
         for (let i = 0, n = data.length; i < n; i++) {
             indices[i] = i;
@@ -142,7 +163,7 @@ export function updateJob(jobResult) {
             jobResult.sortedRows.push(indices);
         }
     }
-    if (jobResult.by == null) {
+    if (jobResult.by === undefined) {
         jobResult.by = jobResult.fields[0];
         for (let i = 0; i < jobResult.fields.length; i++) {
             if (jobResult.fields[i].toLowerCase().indexOf('score') !== -1) {
@@ -151,16 +172,19 @@ export function updateJob(jobResult) {
             }
         }
     }
-    if (jobResult.color == null) {
+    if (jobResult.sortByGroup === undefined) {
+        jobResult.sortByGroup = jobResult.groups[0];
+    }
+    if (jobResult.color === undefined) {
         jobResult.color = jobResult.fields[0];
     }
-    if (jobResult.size == null) {
+    if (jobResult.size === undefined) {
         jobResult.size = jobResult.fields[0];
     }
-    if (jobResult.rowSortOrder == null) {
+    if (jobResult.rowSortOrder === undefined) {
         jobResult.rowSortOrder = [];
     }
-    if (jobResult.rows == null) {
+    if (jobResult.rows === undefined) {
         sortAndFilterJobResult(jobResult);
     }
 
@@ -183,8 +207,13 @@ export function updateJob(jobResult) {
     }
 
     // color='logfoldchanges', size='pvals_adj',
-    if (jobResult.colorScale == null) {
-        let domain = getRange(jobResult.color);
+    if (jobResult.colorScale === undefined) {
+        let domain;
+        if (jobResult.interpolator.scale !== INTERPOLATOR_SCALING_NONE) {
+            domain = [0, 1];
+        } else {
+            domain = getRange(jobResult.color);
+        }
         // if (isNaN(jobResult.options.min) && isNaN(jobResult.options.max) && domain[0] < 0 && domain[1] > 0) {
         //     const max = Math.max(Math.abs(domain[0]), Math.abs(domain[1]));
         //     domain[0] = -max;
@@ -198,18 +227,22 @@ export function updateJob(jobResult) {
         }
         jobResult.colorScale = createColorScale(jobResult.interpolator).domain(domain);
     }
-    if (jobResult.sizeScaleReversed == null) {
-        jobResult.sizeScaleReversed = false;
+    if (jobResult.sizeScaleReversed === undefined) {
+        jobResult.sizeScaleReversed = jobResult.size != null && jobResult.size.indexOf('pval') !== -1;
     }
-    if (jobResult.sizeScale == null) {
-        let domain = getRange(jobResult.size);
-        if (!isNaN(jobResult.options.minSize)) {
-            domain[0] = jobResult.options.minSize;
+    if (jobResult.sizeScale === undefined) {
+        if (jobResult.size !== '(None)') {
+            let domain = getRange(jobResult.size);
+            if (!isNaN(jobResult.options.minSize)) {
+                domain[0] = jobResult.options.minSize;
+            }
+            if (!isNaN(jobResult.options.maxSize)) {
+                domain[1] = jobResult.options.maxSize;
+            }
+            jobResult.sizeScale = scaleLinear().domain(domain).range(jobResult.sizeScaleReversed ? [18, 2] : [2, 18]).clamp(true);
+        } else {
+            jobResult.sizeScale = scaleConstantRange(18);
         }
-        if (!isNaN(jobResult.options.maxSize)) {
-            domain[1] = jobResult.options.maxSize;
-        }
-        jobResult.sizeScale = scaleLinear().domain(domain).range(jobResult.sizeScaleReversed ? [18, 2] : [2, 18]).clamp(true);
     }
 }
 
@@ -219,7 +252,7 @@ export function sortAndFilterJobResult(jobResult) {
     const groups = jobResult.groups;
     const ngroups = groups.length;
     jobResult.sortedRows = [];
-    // sort
+    // sort each group
     for (let groupIndex = 0; groupIndex < ngroups; groupIndex++) {
         const indices = [];
         for (let i = 0, n = jobResult.data.length; i < n; i++) {
@@ -282,16 +315,23 @@ export function sortAndFilterJobResult(jobResult) {
         jobResult.sortedFilteredRows.push(filteredIndices);
     }
     updateTopNJobResult(jobResult);
-
 }
 
+
 export function updateTopNJobResult(jobResult) {
     let indices = new Set();
-    for (let groupIndex = 0; groupIndex < jobResult.groups.length; groupIndex++) {
-        const groupIndices = jobResult.sortedFilteredRows[groupIndex];
+    const index = jobResult.groups.indexOf(jobResult.sortByGroup);
+    const groupOrder = [index];
+    for (let i = 0; i < jobResult.groups.length; i++) {
+        if (i !== index) {
+            groupOrder.push(i);
+        }
+    }
+    for (let i = 0; i < jobResult.groups.length; i++) {
+        const groupIndices = jobResult.sortedFilteredRows[groupOrder[i]];
         const ntop = Math.min(jobResult.ntop, groupIndices.length);
-        for (let i = 0; i < ntop; i++) {
-            indices.add(groupIndices[i]);
+        for (let featureIndex = 0; featureIndex < ntop; featureIndex++) {
+            indices.add(groupIndices[featureIndex]);
         }
     }
     jobResult.rows = Array.from(indices);
@@ -318,6 +358,19 @@ class JobResultsPanel extends React.PureComponent {
         this.setState({showDialog: false});
     };
 
+    onDeleteJob = (event, job) => {
+        event.stopPropagation();
+        this.setState({browseJob: job});
+    };
+
+    onDeleteJobOK = (id) => {
+        this.props.onDeleteJob(id);
+        this.setState({browseJob: null});
+    };
+
+    onDeleteJobCancel = () => {
+        this.setState({browseJob: null});
+    };
     getJobResult = (id) => {
         const {jobResults, jobResultId} = this.props;
         if (id == null) {
@@ -326,6 +379,37 @@ class JobResultsPanel extends React.PureComponent {
         return find(jobResults, item => item.id === id);
     };
 
+    exportJobResult = (event) => {
+        const jobResult = this.getJobResult();
+        const output = [];
+        output.push('id');
+        jobResult.columns.forEach(columnIndex => {
+            const group = jobResult.groups[columnIndex];
+            jobResult.fields.forEach(field => {
+                output.push('\t');
+                output.push(group + ':' + field);
+            });
+        });
+        output.push('\n');
+        for (let i = 0; i < jobResult.data.length; i++) {
+            output.push(jobResult.data[i].index);
+            jobResult.columns.forEach(columnIndex => {
+                const group = jobResult.groups[columnIndex];
+                jobResult.fields.forEach(field => {
+                    const fieldName = group + ':' + field;
+                    const value = jobResult.data[i][fieldName];
+                    output.push('\t');
+                    output.push(value);
+                });
+            });
+            output.push('\n');
+        }
+        const blob = new Blob([output.join('')], {
+            type: 'text/plain;charset=utf-8'
+        });
+        window.saveAs(blob, jobResult.name + '.tsv');
+    };
+
     handleClick = (event, row) => {
         event.stopPropagation();
         let searchTokens = this.props.searchTokens;
@@ -339,14 +423,15 @@ class JobResultsPanel extends React.PureComponent {
             }
         }
         if (index === -1) {
-            searchTokens.push({value: feature, type: X_SEARCH_TOKEN});
-            this.props.setTab('embedding');
+            const dataset = this.props.dataset;
+            searchTokens.push({
+                value: feature,
+                type: dataset.obs.indexOf(feature) !== -1 ? FEATURE_TYPE.OBS : FEATURE_TYPE.X
+            });
         } else {
             searchTokens.splice(index, 1);
         }
-
         this.props.onSearchTokens(searchTokens.slice());
-
     };
 
     sortColumns = () => {
@@ -392,12 +477,11 @@ class JobResultsPanel extends React.PureComponent {
     };
 
     render() {
-
-        const {jobResultId, jobResults, classes, searchTokens, tab} = this.props;
+        const {email, jobResultId, jobResults, classes, searchTokens} = this.props;
         const jobResult = this.getJobResult();
         const selectedFeatures = new Set();
         searchTokens.forEach(token => {
-            if (token.type === X_SEARCH_TOKEN) {
+            if (token.type === FEATURE_TYPE.X) {
                 selectedFeatures.add(token.value);
             }
         });
@@ -413,6 +497,9 @@ class JobResultsPanel extends React.PureComponent {
         let headerWidth = 0;
         let headerHeight = 0;
         let maxSize;
+        let valueScale = null;
+        let isSizeScaled = true;
+        let domains;
         if (jobResult != null) {
             // const name = jobResult.name;
             // const params = jobResult.params;
@@ -421,6 +508,42 @@ class JobResultsPanel extends React.PureComponent {
             by = jobResult.by;
             size = jobResult.size;
             groups = jobResult.groups;
+            if (jobResult.interpolator.scale !== INTERPOLATOR_SCALING_NONE) {
+                valueScale = scaleLinear().range([0, 1]);
+                domains = [];
+                if (jobResult.interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_FEATURE) {
+                    jobResult.rows.forEach(row => {
+                        let min = Number.MAX_VALUE;
+                        let max = -Number.MAX_VALUE;
+                        jobResult.columns.forEach(column => {
+                            const group = groups[column];
+                            const colorField = group + ':' + color;
+                            const colorValue = data[row][colorField];
+                            if (colorValue != null && !isNaN(colorValue)) {
+                                min = colorValue < min ? colorValue : min;
+                                max = colorValue > max ? colorValue : max;
+                            }
+                        });
+                        domains.push([min, max]);
+                    });
+                } else if (jobResult.interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_CATEGORY) {
+                    jobResult.columns.forEach(column => {
+                        let min = Number.MAX_VALUE;
+                        let max = -Number.MAX_VALUE;
+                        jobResult.rows.forEach(row => {
+                            const group = groups[column];
+                            const colorField = group + ':' + color;
+                            const colorValue = data[row][colorField];
+                            if (colorValue != null && !isNaN(colorValue)) {
+                                min = colorValue < min ? colorValue : min;
+                                max = colorValue > max ? colorValue : max;
+                            }
+                        });
+                        domains.push([min, max]);
+                    });
+                }
+            }
+            isSizeScaled = jobResult.size !== '(None)';
             for (let i = 0; i < groups.length; i++) {
                 if (groups[i].length > 2) {
                     rotateHeaders = true;
@@ -439,7 +562,8 @@ class JobResultsPanel extends React.PureComponent {
                     headerWidth = Math.max(headerWidth, d.getBoundingClientRect().width);
                 }
                 d.remove();
-                headerWidth = Math.min(headerWidth, 130);
+                headerWidth += 2; // prevent overflow
+                headerWidth = Math.min(headerWidth, 300);
                 headerHeight = Math.cos(45) * headerWidth;
             }
             maxSize = Math.max(jobResult.sizeScale.range()[0], jobResult.sizeScale.range()[1]);
@@ -449,12 +573,27 @@ class JobResultsPanel extends React.PureComponent {
             return (val == null || isNaN(val)) ? "NaN" : numberFormat2f(val);
         }
 
+        let showJobStatus = false;
+        for (let i = 0; i < jobResults.length; i++) {
+            const isPrecomputed = ('' + jobResults[i].id).startsWith('cirro-');
+            if (!isPrecomputed) {
+                showJobStatus = true;
+                break;
+            }
+        }
         const showBrowseJobs = (jobResultId == null && jobResults.length > 0) || jobResults.length > 1;
         return <React.Fragment>
             <Box color="text.primary">
-                {showBrowseJobs &&
-                <Button style={{marginBottom: 8}} size={"small"} onClick={this.onBrowseJobs} variant="outlined"
-                        color="primary">Browse All Results</Button>}
+                <Grid container alignItems="center" className={classes.toolbar}>
+                    {showBrowseJobs &&
+                    <Button size={"small"} onClick={this.onBrowseJobs} variant="outlined"
+                            color="primary">Browse All Results</Button>}
+                    {showBrowseJobs && jobResult && <Divider orientation="vertical" flexItem/>}
+                    {jobResult && <Button size={"small"} onClick={this.exportJobResult}
+                                          variant="outlined"
+                                          color="primary">Export</Button>}
+                </Grid>
+
                 {jobResult && <React.Fragment>
                     <Typography
                         style={{marginBottom: headerHeight + 8}}
@@ -462,7 +601,7 @@ class JobResultsPanel extends React.PureComponent {
                         color={"textPrimary"}><b>{jobResult.name}</b>&nbsp;
                         <small>{intFormat(rows.length) + ' / ' + intFormat(jobResult.data.length) + ' features'}</small></Typography>
                     <div style={{paddingTop: 6}}>
-                        <Table stickyHeader={true} className={classes.table}>
+                        {jobResult.rows.length > 0 && <Table stickyHeader={true} className={classes.table}>
                             <TableHead>
                                 <TableRow>
                                     <TableCell style={{backgroundColor: 'unset', textAlign: 'center'}}
@@ -487,10 +626,14 @@ class JobResultsPanel extends React.PureComponent {
                                 </TableRow>
                             </TableHead>
                             <TableBody>
-                                {rows.map(row => {
+                                {rows.map((row, rowIndex) => {
                                     const id = data[row]['index'];
                                     const selected = selectedFeatures.has(id);
+                                    if (jobResult.interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_FEATURE) {
+                                        valueScale.domain(domains[rowIndex]);
+                                    }
                                     return <TableRow
+                                        className={classes.tr}
                                         hover
                                         onClick={(event) => this.handleClick(event, row)}
                                         role="checkbox"
@@ -499,7 +642,7 @@ class JobResultsPanel extends React.PureComponent {
                                     ><TableCell className={classes.rowHeader} component="th"
                                                 key={'id'}><Checkbox className={classes.checkbox}
                                                                      checked={selected}/>{id}</TableCell>
-                                        {jobResult.columns.map(column => {
+                                        {jobResult.columns.map((column, columnIndex) => {
                                             const group = groups[column];
                                             const colorField = group + ':' + color;
                                             const sizeField = group + ':' + size;
@@ -507,11 +650,23 @@ class JobResultsPanel extends React.PureComponent {
                                             const colorValue = data[row][colorField];
                                             const sizeValue = data[row][sizeField];
                                             const byValue = data[row][byField];
+                                            let title = by + ':' + formatNumber(byValue);
+                                            if (color !== by) {
+                                                title += ', ' + color + ':' + formatNumber(colorValue);
+                                            }
+                                            if (size !== by && isSizeScaled && size !== color) {
+                                                title += ', ' + size + ':' + formatNumber(sizeValue);
+                                            }
+                                            if (colorValue == null || isNaN(colorValue)) {
+                                                return <TableCell className={classes.td} title={title}
+                                                                  key={group}/>;
+                                            }
                                             const diameter = jobResult.sizeScale(sizeValue);
-                                            const title = by + ':' + formatNumber(byValue) + ', '
-                                                + color + ':' + formatNumber(colorValue) +
-                                                ', ' + size + ':' + formatNumber(sizeValue);
-
+                                            if (jobResult.interpolator.scale === INTERPOLATOR_SCALING_MIN_MAX_CATEGORY) {
+                                                valueScale.domain(domains[columnIndex]);
+                                            }
+                                            const colorValueScaled = valueScale ? valueScale(colorValue) : colorValue;
+                                            const backgroundColor = jobResult.colorScale(colorValueScaled);
                                             return <TableCell className={classes.td} title={title}
                                                               key={group}>
                                                 <div className={classes.dot}
@@ -519,46 +674,86 @@ class JobResultsPanel extends React.PureComponent {
                                                          marginLeft: (maxSize - diameter) / 2,
                                                          width: diameter,
                                                          height: diameter,
-                                                         backgroundColor: jobResult.colorScale(colorValue)
+                                                         backgroundColor: backgroundColor
                                                      }}></div>
                                             </TableCell>;
                                         })}
                                     </TableRow>;
                                 })}
                             </TableBody>
-                        </Table>
+                        </Table>}
                     </div>
                 </React.Fragment>
                 }
             </Box>
+            <Dialog
+                open={this.state.browseJob != null}
+                onClose={this.onDeleteJobCancel}
+                aria-labelledby="confirm-dialog-title"
+                aria-describedby="conform-dialog-description"
+            >
+                <DialogTitle id="confirm-dialog-title">Confirm Delete</DialogTitle>
+                <DialogContent>
+                    <DialogContentText id="confirm-dialog-description">
+                        Are you sure you want to delete {this.state.browseJob ? this.state.browseJob.name : ''}?
+                    </DialogContentText>
+                </DialogContent>
+                <DialogActions>
+                    <Button onClick={this.onDeleteJobCancel}>
+                        Cancel
+                    </Button>
+                    <Button variant="contained" onClick={e => this.onDeleteJobOK(this.state.browseJob.id)}
+                            color="primary"
+                            autoFocus>
+                        OK
+                    </Button>
+                </DialogActions>
+            </Dialog>
             <Dialog onClose={this.onCloseJobs} aria-labelledby="job-results-title"
-                    open={this.state.showDialog || (tab === 'results' && jobResults.length > 1 && jobResult == null)}>
+                    open={this.state.showDialog}>
                 <DialogTitle id="job-results-title" onClose={this.onCloseJobs}>
                     Results
                 </DialogTitle>
-                <DialogContent dividers>
-                    <List style={{width: 500}} dense disablePadding component="nav"
-                          aria-label="results">
-                        {jobResults.map(choice => {
-                            let text = choice.name;
-                            if (choice.title) {
-                                text += ' - ' + choice.title;
-                            }
-                            return <ListItem alignItems="flex-start"
-                                             selected={choice.id === jobResultId}
-                                             key={choice.id}
-                                             button
-                                             onClick={(e) => this.onSelectJob(choice.id)}>
-                                <ListItemText
-                                    primary={text}
-                                    style={{
-                                        textOverflow: 'ellipsis',
-                                        overflow: 'hidden',
-                                        whiteSpace: 'nowrap'
-                                    }}/>
-                            </ListItem>;
-                        })}
-                    </List>
+                <DialogContent>
+                    <Table size="small" stickyHeader={true}>
+                        <TableHead>
+                            <TableRow>
+                                <TableCell>Name</TableCell>
+                                <TableCell>Type</TableCell>
+                                {showJobStatus && <TableCell>Status</TableCell>}
+                            </TableRow>
+                        </TableHead>
+                        <TableBody>
+                            {jobResults.map(jobResult => {
+                                let text = jobResult.name;
+                                if (jobResult.title) {
+                                    text += ' - ' + jobResult.title;
+                                }
+                                const isPrecomputed = ('' + jobResult.id).startsWith('cirro-');
+                                const isComplete = isPrecomputed || jobResult.status === 'complete';
+                                const jobType = jobResult.type === 'de' ? 'Differential Expression' : 'Correlation';
+                                const status = isPrecomputed ? 'complete' : jobResult.status;
+                                // const date = isPrecomputed ? '' : jobResult.submitted;
+                                return <TableRow key={jobResult.id}
+                                                 className={classes.deleteTr}
+                                                 hover
+                                                 selected={jobResult.id === jobResultId}
+                                                 onClick={isComplete ? (event) => this.onSelectJob(jobResult.id) : null}
+                                                 role="checkbox"
+                                                 tabIndex={-1}>
+                                    <TableCell>{text}</TableCell>
+                                    <TableCell>{jobType}</TableCell>
+                                    {showJobStatus && <TableCell>{status}
+                                        {email == jobResult.email && !isPrecomputed &&
+                                        <IconButton edge="end" aria-label="delete"
+                                                    onClick={(event) => this.onDeleteJob(event, jobResult)}>
+                                            <DeleteIcon/>
+                                        </IconButton>}</TableCell>}
+                                </TableRow>;
+                            })}
+                        </TableBody>
+                    </Table>
+
                 </DialogContent>
             </Dialog>
         </React.Fragment>;
@@ -568,6 +763,8 @@ class JobResultsPanel extends React.PureComponent {
 
 const mapStateToProps = state => {
         return {
+            dataset: state.dataset,
+            email: state.email,
             jobResultId: state.jobResult,
             jobResults: state.jobResults,
             searchTokens: state.searchTokens,
@@ -580,6 +777,9 @@ const mapDispatchToProps = (dispatch, ownProps) => {
             onSearchTokens: (payload) => {
                 dispatch(setSearchTokensDirectly(payload));
             },
+            onDeleteJob: (payload) => {
+                dispatch(deleteJobResult(payload));
+            },
             setTab: (payload) => {
                 dispatch(setTab(payload));
             },
