@@ -133,4 +133,14 @@ export class RestServerApi {
             }).then(result => result.json());
     }
 
+    submitJob(data) {
+        return fetch(API + '/submit_job',
+            {
+                body: JSON.stringify(data),
+                method: 'POST',
+                headers: {'Authorization': 'Bearer ' + getIdToken()},
+            }).then(response => response.json());
+    }
+
+
 }
