@@ -275,10 +275,10 @@ class ScatterChartThree extends React.PureComponent {
     };
 
 
-    onEditSelection = () => {
-        this.props.chartOptions.editSelection = !this.props.chartOptions.editSelection;
-        this.props.setChartOptions(this.props.chartOptions);
-    };
+    // onEditSelection = () => {
+    //     this.props.chartOptions.editSelection = !this.props.chartOptions.editSelection;
+    //     this.props.setChartOptions(this.props.chartOptions);
+    // };
 
 
     resetCamera = () => {
@@ -414,14 +414,14 @@ class ScatterChartThree extends React.PureComponent {
                 }
 
             };
-            this.scatterPlot.lassoCallback = (points) => {
+            this.scatterPlot.lassoCallback = (points, appendToSelection) => {
                 const traceInfo = this.props.traceInfo;
                 const positions = traceInfo.positions;
                 const camera = this.scatterPlot.camera;
                 const widthHalf = this.props.chartSize.width / 2;
                 const heightHalf = this.props.chartSize.height / 2;
                 const pos = new Vector3();
-                const selectedIndices = [];
+                const selectedIndices = new Set();
 
                 for (let i = 0, j = 0, k = 0; i < traceInfo.npoints; i++, j += 4, k += 3) {
                     pos.x = positions[k];
@@ -431,21 +431,21 @@ class ScatterChartThree extends React.PureComponent {
                     pos.x = (pos.x * widthHalf) + widthHalf;
                     pos.y = -(pos.y * heightHalf) + heightHalf;
                     if (isPointInside(pos, points)) {
-                        selectedIndices.push(i);
+                        selectedIndices.add(i);
                     }
                 }
 
-                if (selectedIndices.length === 0) {
-                    this.props.onDeselect({name: getEmbeddingKey(traceInfo.embedding)});
+                if (selectedIndices.size === 0) {
+                    this.props.onSelected({name: getEmbeddingKey(traceInfo.embedding)});
                 } else {
                     this.props.onSelected({
                         name: getEmbeddingKey(traceInfo.embedding),
-                        clear: !this.props.chartOptions.editSelection,
-                        value: {basis: traceInfo.embedding, points: selectedIndices}
+                        clear: !appendToSelection,
+                        value: {basis: traceInfo.embedding, indices: selectedIndices}
                     });
                 }
             };
-            this.scatterPlot.boxCallback = (rect) => {
+            this.scatterPlot.boxCallback = (rect, appendToSelection) => {
                 if (this.scatterPlot.interactionMode === 'PAN') {
                     return;
                 }
@@ -455,7 +455,7 @@ class ScatterChartThree extends React.PureComponent {
                 const widthHalf = this.props.chartSize.width / 2;
                 const heightHalf = this.props.chartSize.height / 2;
                 const pos = new Vector3();
-                const selectedPoints = [];
+                const selectedIndices = new Set();
 
                 for (let i = 0, j = 0, k = 0; i < traceInfo.npoints; i++, j += 4, k += 3) {
                     pos.x = positions[k];
@@ -465,17 +465,17 @@ class ScatterChartThree extends React.PureComponent {
                     pos.x = (pos.x * widthHalf) + widthHalf;
                     pos.y = -(pos.y * heightHalf) + heightHalf;
                     if (pos.x >= rect.x && pos.x <= (rect.x + rect.width) && pos.y >= rect.y && pos.y <= (rect.y + rect.height)) {
-                        selectedPoints.push(i);
+                        selectedIndices.add(i);
                     }
                 }
 
-                if (selectedPoints.length === 0) {
-                    this.props.onDeselect({name: getEmbeddingKey(traceInfo.embedding)});
+                if (selectedIndices.size === 0) {
+                    this.props.onSelected({name: getEmbeddingKey(traceInfo.embedding)});
                 } else {
                     this.props.onSelected({
                         name: getEmbeddingKey(traceInfo.embedding),
-                        clear: !this.props.chartOptions.editSelection,
-                        value: {basis: traceInfo.embedding, points: selectedPoints}
+                        clear: !appendToSelection,
+                        value: {basis: traceInfo.embedding, indices: selectedIndices}
                     });
                 }
             };
@@ -520,7 +520,7 @@ class ScatterChartThree extends React.PureComponent {
             <div className={this.props.classes.root}>
                 <ChartToolbar
                     dragmode={this.props.chartOptions.dragmode}
-                    editSelection={this.props.chartOptions.editSelection}
+                    // editSelection={this.props.chartOptions.editSelection}
                     onGallery={this.props.onGallery}
                     animating={this.props.chartOptions.animating}
                     showFog={this.props.chartOptions.showFog}
@@ -530,7 +530,7 @@ class ScatterChartThree extends React.PureComponent {
                     onSaveImage={this.onSaveImage}
                     onDragMode={this.onDragMode}
                     onCopyImage={this.onCopyImage}
-                    onEditSelection={this.onEditSelection}
+                    // onEditSelection={this.onEditSelection}
                     onShowAxis={this.onShowAxis}
                     onHome={this.resetCamera}
                     showAxis={this.props.chartOptions.showAxis}
