@@ -1,12 +1,12 @@
 import {isPlainObject} from 'lodash';
+import natsort from 'natsort';
 import {combineReducers} from 'redux';
 import {
     ADD_DATASET,
     DELETE_DATASET,
     getTraceKey,
     RESTORE_VIEW,
-    SET_BIN_SUMMARY,
-    SET_BIN_VALUES,
+    SET_ACTIVE_FEATURE,
     SET_CATEGORICAL_COLOR,
     SET_CATEGORICAL_NAME,
     SET_CHART_OPTIONS,
@@ -34,10 +34,8 @@ import {
     SET_MARKER_OPACITY,
     SET_MARKERS,
     SET_MESSAGE,
-    SET_NUMBER_OF_BINS,
     SET_POINT_SIZE,
     SET_PRIMARY_CHART_SIZE,
-    SET_PRIMARY_TRACE_KEY,
     SET_SAVED_DATASET_STATE,
     SET_SEARCH_TOKENS,
     SET_SELECTED_DISTRIBUTION_DATA,
@@ -49,7 +47,14 @@ import {
     SET_USER,
     UPDATE_DATASET,
 } from '../actions';
-import {createColorScale, getInterpolator, updateTraceColors} from '../util';
+import {createCategoryToStats} from '../MetaEmbedding';
+import {
+    createColorScale,
+    getInterpolator,
+    INTERPOLATOR_SCALING_NONE,
+    TRACE_TYPE_META_IMAGE,
+    updateTraceColors
+} from '../util';
 
 export const DEFAULT_BIN_SUMMARY = 'max';
 export const DEFAULT_NUMBER_BINS = 500;
@@ -57,7 +62,7 @@ export const DEFAULT_POINT_SIZE = 1;
 export const DEFAULT_MARKER_OPACITY = 1;
 export const DEFAULT_UNSELECTED_MARKER_OPACITY = 0.1;
 export const DEFAULT_INTERPOLATOR = 'Viridis';
-export const DEFAULT_DOT_PLOT_INTERPOLATOR = 'Reds';
+export const DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR = 'Reds';
 export const DEFAULT_DRAG_MODE = 'pan';
 export const DEFAULT_SHOW_LABELS = false;
 export const DEFAULT_SHOW_AXIS = true;
@@ -80,22 +85,23 @@ const DEFAULT_INTERPOLATOR_OBJ = {
     reversed: false
 };
 
-const DEFAULT_DOT_PLOT_INTERPOLATOR_OBJ = {
-    name: DEFAULT_DOT_PLOT_INTERPOLATOR,
-    value: getInterpolator(DEFAULT_DOT_PLOT_INTERPOLATOR),
-    reversed: false
+const DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR_OBJ = {
+    name: DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR,
+    value: getInterpolator(DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR),
+    reversed: false,
+    scale: INTERPOLATOR_SCALING_NONE
 };
 
 
 const DEFAULT_PRIMARY_CHART_SIZE = {
     width: window.innerWidth - 280,
-    height: Math.max(300, window.innerHeight - 410)
+    height: Math.max(300, window.innerHeight - 370)
 };
 
 const DEFAULT_CHART_OPTIONS = {
     animating: false,
     dragmode: DEFAULT_DRAG_MODE,
-    editSelection: false,
+    showGalleryLabels: false,
     showAxis: DEFAULT_SHOW_AXIS,
     showFog: DEFAULT_SHOW_FOG,
     darkMode: DEFAULT_DARK_MODE,
@@ -304,48 +310,6 @@ function markers(state = [], action) {
 }
 
 
-function binSummary(state = DEFAULT_BIN_SUMMARY, action) {
-    switch (action.type) {
-        case SET_BIN_SUMMARY:
-            return action.payload;
-        case SET_DATASET:
-            return DEFAULT_BIN_SUMMARY;
-        case RESTORE_VIEW:
-            return action.payload.binSummary != null ? action.payload.binSummary : state;
-        default:
-            return state;
-    }
-}
-
-
-function binValues(state = false, action) {
-    switch (action.type) {
-        case SET_BIN_VALUES:
-            return action.payload;
-        case SET_DATASET:
-            return false;
-        case RESTORE_VIEW:
-            return action.payload.binValues != null ? action.payload.binValues : state;
-        default:
-            return state;
-    }
-}
-
-
-function numberOfBins(state = DEFAULT_NUMBER_BINS, action) {
-    switch (action.type) {
-        case SET_NUMBER_OF_BINS:
-            return action.payload;
-        case SET_DATASET:
-            return DEFAULT_NUMBER_BINS;
-        case RESTORE_VIEW:
-            return action.payload.numberOfBins != null ? action.payload.numberOfBins : state;
-        default:
-            return state;
-    }
-}
-
-
 function markerOpacity(state = DEFAULT_MARKER_OPACITY, action) {
     switch (action.type) {
         case SET_MARKER_OPACITY:
@@ -400,16 +364,13 @@ function user(state = {}, action) {
     }
 }
 
-/**
- * Object that contains count (number), chart (object). Each key in chart is the full layout name. Each value contains
- * userPoints (selected points in chart space) and points (the selected points in bin space if binning)
- */
-function selection(state = {chart: {}}, action) {
+
+function selection(state = new Set(), action) {
     switch (action.type) {
         case SET_SELECTION:
             return action.payload;
         case SET_DATASET:
-            return {};
+            return new Set();
         default:
             return state;
     }
@@ -486,12 +447,16 @@ function dialog(state = null, action) {
 }
 
 
-function dotPlotInterpolator(state = DEFAULT_DOT_PLOT_INTERPOLATOR_OBJ, action) {
+function distributionPlotInterpolator(state = DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR_OBJ, action) {
     switch (action.type) {
         case SET_DISTRIBUTION_PLOT_INTERPOLATOR:
-            return action.payload;
+            return Object.assign({}, DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR_OBJ, action.payload);
         case RESTORE_VIEW:
-            return action.payload.dotPlotInterpolator != null ? action.payload.dotPlotInterpolator : state;
+            if (action.payload.distributionPlotInterpolator != null) {
+                const interpolator = Object.assign({}, DEFAULT_DISTRIBUTION_PLOT_INTERPOLATOR_OBJ, action.payload.distributionPlotInterpolator);
+                interpolator.value = getInterpolator(interpolator.name);
+                return interpolator;
+            }
         default:
             return state;
     }
@@ -632,52 +597,94 @@ function cachedData(state = {}, action) {
             return {};
     }
     return state;
+}
 
+function sortEmbeddingTraces(traces) {
+    const sorter = natsort({insensitive: true});
+    // sort by feature insertion order, then embedding
+    const featureToMinIndex = {};
+    for (let i = 0; i < traces.length; i++) {
+        let prior = featureToMinIndex[traces[i].name];
+        let index = i;
+        if (prior !== undefined) {
+            index = Math.min(index, prior);
+        }
+        featureToMinIndex[traces[i].name] = index;
+    }
+    traces.sort((a, b) => {
+        if (a.name === b.name) {
+            const val = sorter(a.embedding.name, b.embedding.name);
+            if (val !== 0) {
+                return val;
+            }
+        }
+        // sortIndex added if user drags and drops gallery chart
+        const index1 = a.sortIndex !== undefined ? a.sortIndex : featureToMinIndex[a.name];
+        const index2 = b.sortIndex !== undefined ? b.sortIndex : featureToMinIndex[b.name];
+        return index1 - index2;
+    });
+    return traces;
 }
 
 // each item has  data (list of traces, each trace has x, y, etc.), layout
 function embeddingData(state = [], action) {
     switch (action.type) {
         case SET_EMBEDDING_DATA :
-            return action.payload;
+            return sortEmbeddingTraces(action.payload);
         case SET_SELECTION:
+            state.forEach(trace => {
+                if (trace.type === TRACE_TYPE_META_IMAGE) {
+                    trace.categoryToStats = action.payload.size === 0 ? trace.fullCategoryToStats : createCategoryToStats(trace, action.payload);
+                    updateTraceColors(trace);
+                }
+            });
             return state.slice();
         case SET_DOMAIN:
-            state.forEach((traceInfo, stateIndex) => {
-                if (traceInfo.continuous && traceInfo.name === action.payload.name) {
+            state.forEach((trace) => {
+                if (trace.continuous && trace.name === action.payload.name) {
                     const summary = action.payload.summary;
-                    let domain = [summary.min, summary.max];
-                    if (summary.customMin != null && !isNaN(summary.customMin)) {
-                        domain[0] = summary.customMin;
+                    const domain = trace.type === TRACE_TYPE_META_IMAGE ? [-3, 3] : [summary.min, summary.max];
+
+                    if (trace.type === TRACE_TYPE_META_IMAGE) {
+                        if (summary.customZMin != null && !isNaN(summary.customZMin)) {
+                            domain[0] = summary.customZMin;
+                        }
+                        if (summary.customZMax != null && !isNaN(summary.customZMax)) {
+                            domain[1] = summary.customZMax;
+                        }
+                    } else {
+                        if (summary.customMin != null && !isNaN(summary.customMin)) {
+                            domain[0] = summary.customMin;
+                        }
+                        if (summary.customMax != null && !isNaN(summary.customMax)) {
+                            domain[1] = summary.customMax;
+                        }
                     }
-                    if (summary.customMax != null && !isNaN(summary.customMax)) {
-                        domain[1] = summary.customMax;
-                    }
-                    traceInfo.colorScale.domain(domain);
-                    updateTraceColors(traceInfo);
+
+                    trace.colorScale.domain(domain);
+                    updateTraceColors(trace);
                 }
             });
             return state.slice();
         case SET_CATEGORICAL_COLOR:
-            state.forEach((traceInfo, stateIndex) => {
-                if (!traceInfo.continuous && traceInfo.name === action.payload.name) {
-                    let index = traceInfo.colorScale.domain().indexOf(action.payload.value);
-                    let range = traceInfo.colorScale.range();
+            state.forEach((trace) => {
+                if (!trace.continuous && trace.name === action.payload.name) {
+                    let index = trace.colorScale.domain().indexOf(action.payload.value);
+                    let range = trace.colorScale.range();
                     range[index] = action.payload.color;
-                    traceInfo.colorScale.range(range);
-                    updateTraceColors(traceInfo);
+                    trace.colorScale.range(range);
+                    updateTraceColors(trace);
                 }
             });
             return state.slice();
 
         case SET_INTERPOLATOR:
             // update colors for existing continuous traces
-
-            state.forEach((traceInfo, stateIndex) => {
-                if (traceInfo.continuous) {
-                    let domain = traceInfo.colorScale.domain();
-                    traceInfo.colorScale = createColorScale(action.payload).domain(domain);
-                    updateTraceColors(traceInfo);
+            state.forEach((trace) => {
+                if (trace.continuous) {
+                    let domain = trace.colorScale.domain();
+                    trace.colorScale = createColorScale(action.payload).domain(domain);
+                    updateTraceColors(trace);
                 }
             });
             return state.slice();
@@ -710,18 +717,21 @@ export function savedDatasetState(state = {}, action) {
     }
 }
 
-export function primaryTraceKey(state = null, action) {
+// object with name, type, embeddingKey
+export function activeFeature(state = {}, action) {
     switch (action.type) {
         case SET_DATASET:
             return null;
-        case SET_PRIMARY_TRACE_KEY:
+        case SET_ACTIVE_FEATURE:
             return action.payload;
         case SET_EMBEDDING_DATA:
-            let traces = action.payload.filter(traceInfo => traceInfo.active);
+            let traces = action.payload.filter(trace => trace.active);
             if (traces.length === 0) {
                 return null;
             }
-            return getTraceKey(traces[traces.length - 1]); // last feature becomes primary
+            const trace = traces[traces.length - 1];
+            const embeddingKey = getTraceKey(trace); // last feature becomes primary
+            return {name: trace.name, type: trace.featureType, embeddingKey: embeddingKey};
         default:
             return state;
     }
@@ -749,8 +759,7 @@ function interpolator(state = DEFAULT_INTERPOLATOR_OBJ, action) {
 }
 
 export default combineReducers({
-    binSummary,
-    binValues,
+    activeFeature,
     cachedData,
     categoricalNames,
     chartOptions,
@@ -763,7 +772,7 @@ export default combineReducers({
     dialog,
     distributionData,
     distributionPlotOptions,
-    dotPlotInterpolator,
+    distributionPlotInterpolator,
     email,
     embeddingData,
     embeddingLabels,
@@ -778,10 +787,8 @@ export default combineReducers({
     markerOpacity,
     markers,
     message,
-    numberOfBins,
     pointSize,
     primaryChartSize,
-    primaryTraceKey,
     savedDatasetState,
     searchTokens,
     selectedDistributionData,
@@ -790,5 +797,4 @@ export default combineReducers({
     tab,
     unselectedMarkerOpacity,
     user
-
 });
