@@ -66,12 +66,41 @@ export const CATEGORY_20C = [
     '#74c476', '#a1d99b', '#c7e9c0', '#756bb1', '#9e9ac8', '#bcbddc',
     '#dadaeb', '#636363', '#969696', '#bdbdbd', '#d9d9d9'];
 
-export const OBS_SEARCH_TOKEN = 'obs';
-export const OBS_CAT_SEARCH_TOKEN = 'obsCat';
-export const X_SEARCH_TOKEN = 'X';
-export const FEATURE_SET_SEARCH_TOKEN = 'featureSet';
-export const METAFEATURE_SEARCH_TOKEN = 'metafeature';
-export const FEATURE_SET_SEARCH_TOKEN_ADD = 'featureSetAdd';
+export const FEATURE_TYPE = {
+    OBS: 'obs',
+    OBS_CAT: 'obsCat',
+    X: 'X',
+    FEATURE_SET: 'featureSet',
+    METAFEATURE: 'metafeature',
+    COUNT: 'count'
+};
+
+export const TRACE_TYPE_IMAGE = 'image';
+export const TRACE_TYPE_SCATTER = 'scatter';
+export const TRACE_TYPE_META_IMAGE = 'meta_image';
+
+export const INTERPOLATOR_SCALING_MIN_MAX_FEATURE = 'min_max_feature';
+export const INTERPOLATOR_SCALING_MIN_MAX_CATEGORY = 'min_max_category';
+export const INTERPOLATOR_SCALING_NONE = 'none';
+
+export function scaleConstantRange(value) {
+
+    function scale(x) {
+        return value;
+    }
+
+    scale.invert = scale;
+    scale.domain = scale.range = function (_) {
+        return arguments.length ? (value = _[0]) : [value, value];
+    };
+
+    scale.copy = function () {
+        return scaleConstantRange(value);
+    };
+
+
+    return scale;
+}
 
 export function stripTrailingZeros(s) {
     let index = s.lastIndexOf('.');
@@ -142,7 +171,7 @@ export function setClipboardData(clipboardData) {
 };
 
 export function updateTraceColors(traceInfo) {
-    if (traceInfo.type === 'image') {
+    if (traceInfo.type === TRACE_TYPE_IMAGE) {
         let colors = [];
         let colorScale = traceInfo.colorScale;
         const colorMapper = rgb => rgb.formatHex();
@@ -151,24 +180,51 @@ export function updateTraceColors(traceInfo) {
             colors.push(colorMapper(rgb));
         }
         traceInfo.colors = colors;
-    } else if (traceInfo.type === 'scatter') {
+    } else if (traceInfo.type === TRACE_TYPE_SCATTER) {
         traceInfo.colors = getColors(traceInfo);
-    } else if (traceInfo.type === 'meta_image') {
+    } else if (traceInfo.type === TRACE_TYPE_META_IMAGE) {
         let colorScale = traceInfo.colorScale;
         const svgNode = traceInfo.source;
         const galleryNode = traceInfo.gallerySource;
         const categoryToStats = traceInfo.categoryToStats;
-        if (categoryToStats) {
+        if (traceInfo.name !== '__count') {
             for (const category in categoryToStats) {
                 const stats = categoryToStats[category];
                 const query = category.replaceAll(' ', '_'); // FIXME
-
                 svgNode.querySelectorAll('[id="' + query + '"]').forEach(node => {
-                    node.style.fill = colorScale(stats.value);
+                    const color = stats.value === undefined ? '#f0f0f0' : colorScale(stats.value);
+                    node.style.fill = color;
                 });
 
                 galleryNode.querySelectorAll('[id="' + query + '"]').forEach(node => {
-                    node.style.fill = colorScale(stats.value);
+                    const color = stats.value === undefined ? '#f0f0f0' : colorScale(stats.value);
+                    node.style.fill = color;
+                });
+            }
+        } else {
+            for (const category in categoryToStats) {
+                const stats = categoryToStats[category];
+                const query = category.replaceAll(' ', '_'); // FIXME
+                svgNode.querySelectorAll('[id="' + query + '"]').forEach(node => {
+                    if (stats.n === 0) {
+                        if (node.dataset.fill === undefined) {
+                            node.dataset.fill = node.style.fill;
+                        }
+                        node.style.fill = '#f0f0f0';
+                    } else if (node.dataset.fill !== undefined) {
+                        node.style.fill = node.dataset.fill;
+                    }
+                });
+
+                galleryNode.querySelectorAll('[id="' + query + '"]').forEach(node => {
+                    if (stats.n === 0) {
+                        if (node.dataset.fill === undefined) {
+                            node.dataset.fill = node.style.fill;
+                        }
+                        node.style.fill = '#f0f0f0';
+                    } else if (node.dataset.fill !== undefined) {
+                        node.style.fill = node.dataset.fill;
+                    }
                 });
             }
         }
@@ -317,7 +373,7 @@ export function getInterpolator(name) {
 }
 
 export function createColorScale(colorScaleDef) {
-    const scale = scaleSequential(colorScaleDef.value).clamp(true);
+    const scale = scaleSequential(colorScaleDef.value).clamp(true).unknown('#f0f0f0');
     if (colorScaleDef.reversed) {
         const interpolator = scale.interpolator();
         const mirror = t => interpolator(1 - t);
@@ -384,18 +440,16 @@ export function splitSearchTokens(tokens) {
     let featureSetsAdd = [];
     let metafeatures = [];
     tokens.forEach(token => {
-        if (token.type === X_SEARCH_TOKEN) {
+        if (token.type === FEATURE_TYPE.X) {
             X.push(token.value);
-        } else if (token.type === OBS_SEARCH_TOKEN) {
+        } else if (token.type === FEATURE_TYPE.OBS) {
             obs.push(token.value);
-        } else if (token.type === OBS_CAT_SEARCH_TOKEN) {
+        } else if (token.type === FEATURE_TYPE.OBS_CAT) {
             obsCat.push(token.value);
-        } else if (token.type === FEATURE_SET_SEARCH_TOKEN) {
+        } else if (token.type === FEATURE_TYPE.FEATURE_SET) {
             featureSets.push(token.value);
-        } else if (token.type === METAFEATURE_SEARCH_TOKEN) {
+        } else if (token.type === FEATURE_TYPE.METAFEATURE) {
             metafeatures.push(token.value);
-        } else if (token.type === FEATURE_SET_SEARCH_TOKEN_ADD) {
-            featureSetsAdd.push(token.value);
         } else {
             console.log('Unknown type: ' + token);
         }
